package com.gic.store.dto;

import javax.validation.constraints.*;
import java.io.Serializable;
import java.util.Date;

/** 自定义字段属性DTO
  * @ClassName: StoreFieldDTO 
  * @Description:    自定义字段属性DTO
  * @author guojuxing 
  * @date  2019/6/24 10:29 AM 
  */
public class StoreFieldDTO implements Serializable {
    private static final long serialVersionUID = -3194005371537750579L;


    public interface SaveFieldValidView {
    }

    public interface EditFieldValidView {
    }

    /**
     *
     */
    @NotNull(message = "主键ID不能为空", groups = {EditFieldValidView.class})
    private Integer storeFieldId;

    /**
     * 属性名称
     */
    @NotBlank(message = "属性名称不能为空", groups = {SaveFieldValidView.class, EditFieldValidView.class})
    private String storeFieldName;

    /**
     * 属性code
     */
    private String storeFieldCode;

    /**
     * 字段类型；1文本   2单选  3多选  4实数  5时间
     */
    @NotNull(message = "字段类型不能为空", groups = {SaveFieldValidView.class})
    @Min(value = 1, groups = {SaveFieldValidView.class})
    @Max(value = 5, groups = {SaveFieldValidView.class})
    private Integer storeFieldType;

    /**
     *
     */
    @NotNull(message = "企业ID不能为空", groups = {SaveFieldValidView.class})
    private Integer enterpriseId;

    /**
     * 门店域id
     */
    @NotBlank(message = "门店域不能为空", groups = {SaveFieldValidView.class, EditFieldValidView.class})
    private String storeRegionId;

    /**
     *
     */
    private Integer status;

    /**
     *
     */
    private Date createTime;

    /**
     *
     */
    private Date updateTime;

    /**
     * 字段详细配置
     */
    @NotBlank(message = "字段详细配置不能为空", groups = {SaveFieldValidView.class})
    private String storeFieldDetail;

    /**
     * 与ERP映射的门店字段
     */
    private String erpRelCode;

    /**
     * 排序字段
     */
    private Double sort;
    /**
     * 排序值
     */
    private Integer seq;

    /**
     * 0:owner 1:other 授权者和被授权
     */
    private Integer ownType;

    public Integer getStoreFieldId() {
        return storeFieldId;
    }

    public void setStoreFieldId(Integer storeFieldId) {
        this.storeFieldId = storeFieldId;
    }

    public String getStoreFieldName() {
        return storeFieldName;
    }

    public void setStoreFieldName(String storeFieldName) {
        this.storeFieldName = storeFieldName;
    }

    public String getStoreFieldCode() {
        return storeFieldCode;
    }

    public void setStoreFieldCode(String storeFieldCode) {
        this.storeFieldCode = storeFieldCode;
    }

    public Integer getStoreFieldType() {
        return storeFieldType;
    }

    public void setStoreFieldType(Integer storeFieldType) {
        this.storeFieldType = storeFieldType;
    }

    public Integer getEnterpriseId() {
        return enterpriseId;
    }

    public void setEnterpriseId(Integer enterpriseId) {
        this.enterpriseId = enterpriseId;
    }

    public String getStoreRegionId() {
        return storeRegionId;
    }

    public void setStoreRegionId(String storeRegionId) {
        this.storeRegionId = storeRegionId;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public String getStoreFieldDetail() {
        return storeFieldDetail;
    }

    public void setStoreFieldDetail(String storeFieldDetail) {
        this.storeFieldDetail = storeFieldDetail;
    }

    public String getErpRelCode() {
        return erpRelCode;
    }

    public void setErpRelCode(String erpRelCode) {
        this.erpRelCode = erpRelCode;
    }

    public Double getSort() {
        return sort;
    }

    public void setSort(Double sort) {
        this.sort = sort;
    }

    public Integer getSeq() {
        return seq;
    }

    public void setSeq(Integer seq) {
        this.seq = seq;
    }

    public Integer getOwnType() {
        return ownType;
    }

    public void setOwnType(Integer ownType) {
        this.ownType = ownType;
    }

    @Override
    public String toString() {
        return "StoreFieldDTO{" +
                "storeFieldId=" + storeFieldId +
                ", storeFieldName='" + storeFieldName + '\'' +
                ", storeFieldCode='" + storeFieldCode + '\'' +
                ", storeFieldType=" + storeFieldType +
                ", enterpriseId=" + enterpriseId +
                ", storeRegionId='" + storeRegionId + '\'' +
                ", status=" + status +
                ", createTime=" + createTime +
                ", updateTime=" + updateTime +
                ", storeFieldDetail='" + storeFieldDetail + '\'' +
                ", erpRelCode='" + erpRelCode + '\'' +
                ", sort=" + sort +
                ", seq=" + seq +
                ", ownType=" + ownType +
                '}';
    }
}
