package com.gic.store.service;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.store.dto.ClerkDTO;
import com.gic.store.dto.ClerkSearchDTO;
import com.gic.store.dto.ClerkStoreListDTO;
import com.gic.store.dto.clerk.OrderAddClerkDTO;
import com.gic.store.dto.clerk.PosAddClerkDTO;
import com.gic.store.dto.clerk.ProcessBatchClerkDTO;

import java.util.List;

/**
 * @ClassName: ClerkApiService
 * @Description: 导购service 
 * @author zhiwj
 * @date 2019/7/31 11:36
 */
public interface ClerkApiService {
    
    /**
     * 保存或编辑导购
     * @Title: saveOrUpdate
     * @Description: 保存或编辑导购
     * @author zhiwj 
     * @param clerkDTO 导购
     * @return com.gic.api.base.commons.ServiceResponse
     * @throws
     */
    ServiceResponse<Void> saveOrUpdate(ClerkDTO clerkDTO);

    /**
     * 校验导购参数 clerkCode phoneNumber在门店storeInfoId下唯一 手机号是带区号一起判断的
     * @Title: verifyParam
     * @Description:
     * @author zhiwj
     * @param clerkDTO
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Void>
     * @throws
     */
    ServiceResponse<Void> verifyParam(ClerkDTO clerkDTO);

    /**
     * 好办保存或编辑导购
     * @Title: saveOrUpdateFromHaoban
     * @Description:
     * @author zhiwj
     * @param clerkDTO
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Void>
     * @throws
     */
    ServiceResponse<Void> saveOrUpdateFromHaoban(ClerkDTO clerkDTO);

    /**
     * 订单途经保存导购
     * @Title: saveClerkForOrder
     * @Description:
     * @author zhiwj
     * @param clerkName
     * @param clerkCode
     * @param storeInfoId
     * @param enterpriseId
     * @param orderNum
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Integer>
     * @throws
     */
    ServiceResponse<Integer> saveClerkForOrder(String clerkName, String clerkCode, Integer storeInfoId, Integer enterpriseId, String orderNum);

    /**
     * 同步pos会员途经保存导购
     * @Title: saveClerkForPosMember
     * @Description:
     * @author zhiwj
     * @param clerkName
     * @param clerkCode
     * @param storeInfoId
     * @param enterpriseId
     * @param cardNo
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Integer>
     * @throws
     */
    ServiceResponse<Integer> saveClerkForPosMember(String clerkName, String clerkCode, Integer storeInfoId, Integer enterpriseId, String cardNo);
    /**
     * 同步pos会员途经保存导购
     * @Title: saveClerkForPosMember
     * @Description:
     * @author zhiwj
     * @param posAddClerkDTO
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Integer>
     * @throws
     */
    ServiceResponse<Integer> saveClerkForPosMember(PosAddClerkDTO posAddClerkDTO);

    /**
     *  订单途经保存导购
     * @Title: saveClerkByStoreInfoIdForOrder
     * @Description:
     * @author zhiwj
     * @param clerkName
     * @param clerkCode
     * @param storeInfoId
     * @param enterpriseId
     * @param orderNum
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Integer>
     * @throws
     */
    ServiceResponse<Integer> saveClerkByStoreInfoIdForOrder(String clerkName, String clerkCode, Integer storeInfoId, Integer enterpriseId, String orderNum);
    /**
     * 订单途经保存导购
     * @Title: saveClerkByStoreInfoIdForOrder
     * @Description:
     * @author zhiwj
     * @param orderAddClerkDTO
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Integer>
     * @throws
     */
    ServiceResponse<Integer> saveClerkByStoreInfoIdForOrder(OrderAddClerkDTO orderAddClerkDTO);


    /**
     * getClerkByCode  通过导购code查询导购
     * @Title: getClerkByCode
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param clerkCode
     * @param storeId
     * @return com.gic.api.base.commons.ServiceResponse<com.gic.store.dto.ClerkDTO>
     * @throws
     */
    ServiceResponse<ClerkDTO> getClerkByCode(Integer enterpriseId, String clerkCode, Integer storeId);

    /**
     * getClerkByCodeAndStoreInfoId
     * @Title: getClerkByCodeAndStoreInfoId
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param clerkCode
     * @param storeInfoId
     * @return com.gic.api.base.commons.ServiceResponse<com.gic.store.dto.ClerkDTO>
     * @throws
     */
    ServiceResponse<ClerkDTO> getClerkByCodeAndStoreInfoId(Integer enterpriseId, String clerkCode, Integer storeInfoId);
    /**
     * 导购列表
     * @Title: listClerk
     * @Description: 导购列表
     * @author zhiwj
     * @param enterpriseId 企业id
     * @param clerkSearchDTO
     * @param pageNum
     * @param pageSize
     * @return com.gic.api.base.commons.ServiceResponse<com.gic.api.base.commons.Page<com.gic.store.dto.ClerkStoreListDTO>>
     * @throws 
     */
    ServiceResponse<Page<ClerkStoreListDTO>> listClerk(Integer enterpriseId, ClerkSearchDTO clerkSearchDTO, Integer pageNum, Integer pageSize);

    /**
     * 获取clerk总数
     * @Title: getTotalClerk
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param clerkSearchDTO
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Integer>
     * @throws
     */
    ServiceResponse<Integer> getTotalClerk(Integer enterpriseId, ClerkSearchDTO clerkSearchDTO);

    /**
     * 批量修改状态
     * @Title: updateClerkStatus
     * @Description: 批量修改导购状态
     * @author zhiwj 
     * @param enterpriseId 企业id
     * @param clerkIds 导购ids
     * @param status 状态
     * @return com.gic.api.base.commons.ServiceResponse
     * @throws 
     */
    ServiceResponse<Void> updateClerkStatus(Integer enterpriseId, String clerkIds, Integer status);

    /**
     * 查询list通过id
     * @Title: listClerkByIds
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param clerkIds
     * @return java.util.List<com.gic.store.dto.ClerkDTO>
     * @throws
     */
    ServiceResponse<List<ClerkDTO>> listClerkByIds(Integer enterpriseId, String clerkIds);

    /**
     * listClerkByStoreId
     * @Title: listClerkByStoreId
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param storeId
     * @param search
     * @return com.gic.api.base.commons.ServiceResponse<java.util.List<com.gic.store.dto.ClerkDTO>>
     * @throws
     */
    ServiceResponse<List<ClerkDTO>> listClerkByStoreId(Integer enterpriseId, Integer storeId, String search);

    /**
     * listClerkByStoreInfoId
     * @Title: listClerkByStoreInfoId
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param storeInfoId
     * @param search
     * @return com.gic.api.base.commons.ServiceResponse<java.util.List<com.gic.store.dto.ClerkDTO>>
     * @throws
     */
    ServiceResponse<List<ClerkDTO>> listClerkByStoreInfoId(Integer enterpriseId, Integer storeInfoId, String search);

    /**
     * pageClerkByStoreInfoId
     * @Title: pageClerkByStoreInfoId
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param storeInfoId
     * @param search
     * @param pageNum
     * @param pageSize
     * @return com.gic.api.base.commons.ServiceResponse<com.gic.api.base.commons.Page<com.gic.store.dto.ClerkDTO>>
     * @throws
     */
    ServiceResponse<Page<ClerkDTO>> pageClerkByStoreInfoId(Integer enterpriseId, Integer storeInfoId, String search, Integer pageNum, Integer pageSize);

    /**
     * 店长
     * @Title: getHeadClerk 
     * @Description:
     * @author guojuxing
     * @param enterpriseId
     * @param storeId 
     * @return  com.gic.api.base.commons.ServiceResponse<com.gic.store.dto.ClerkDTO> 
     */
    ServiceResponse<ClerkDTO> getHeadClerk(Integer enterpriseId, Integer storeId);

    /**
     * getHeadClerkByStoreInfoId
     * @Title: getHeadClerkByStoreInfoId
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param storeInfoId
     * @return com.gic.api.base.commons.ServiceResponse<com.gic.store.dto.ClerkDTO>
     * @throws
     */
    ServiceResponse<ClerkDTO> getHeadClerkByStoreInfoId(Integer enterpriseId, Integer storeInfoId);

    /**
     * getClerkById
     * @Title: getClerkById
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param clerkId
     * @return com.gic.api.base.commons.ServiceResponse<com.gic.store.dto.ClerkDTO>
     * @throws
     */
    ServiceResponse<ClerkDTO> getClerkById(Integer enterpriseId, Integer clerkId);

    /**
     * listClerk
     * @Title: listClerk
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param search
     * @return com.gic.api.base.commons.ServiceResponse<java.util.List<com.gic.store.dto.ClerkDTO>>
     * @throws
     */
    ServiceResponse<List<ClerkDTO>> listClerk(Integer enterpriseId, String search);

    /**
     * 处理导购 实施运维调用批处理
     * @Title: importClerkForOperation 
     * @Description:
     * @author guojuxing
     * @param clerkInfo 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.String> 
     */
    ServiceResponse<String> importClerkForOperation(ProcessBatchClerkDTO clerkInfo);

    /**
     * 将同样导购的信息添加到另一个门店下
     * @Title: addClerkToOtherStore
     * @Description: 将同样导购的信息添加到另一个门店下
     *  入参 storeId clerkId enterpriseId  判断该导购是否与该门店存在关联，
     *  如果存在返回 门店下 同导购code 的 clerkId ,如果不存在，新建导购，返回新建的导购i
     * @author zhiwj
     * @param clerkId
     * @param storeInfoId
     * @param enterpriseId
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Void>
     * @throws
     */
    ServiceResponse<Integer> addClerkToOtherStore(Integer clerkId, Integer storeInfoId, Integer enterpriseId);

    /**
     * ensureClerkInStore
     * @Title: ensureClerkInStore
     * @Description:
     * @author zhiwj
     * @param clerkId
     * @param storeInfoId
     * @param enterpriseId
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Void>
     * @throws
     */
    ServiceResponse<Boolean> ensureClerkInStore(Integer clerkId, Integer storeInfoId, Integer enterpriseId);

    /**
     * 按店招品牌搜索所有导购
     * @Title: listClerkByStoreBrand
     * @Description: 按店招品牌搜索所有导购
     * @author zhiwj
     * @param enterpriseId
     * @param storeBrandId
     * @param clerkName
     * @return com.gic.api.base.commons.ServiceResponse<java.util.List<com.gic.store.dto.ClerkDTO>>
     * @throws
     */
    ServiceResponse<List<ClerkDTO>> listClerkByStoreBrand(Integer enterpriseId, Integer storeBrandId, String clerkName);

    /**
     * updateClerkLeader
     * @Title: updateClerkLeader
     * @Description:
     * @author zhiwj
     * @param clerkId
     * @return com.gic.api.base.commons.ServiceResponse
     * @throws
     */
    ServiceResponse updateClerkLeader(Integer clerkId);

    /***
     * syncClerkToWeimob
     * @Title: syncClerkToWeimob
     * @Description:
     * @author zhiwj
     * @param wmMallStoreId
     * @param storeIdList
     * @param enterpriseId
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Void>
     * @throws
     */
    ServiceResponse<Void> syncClerkToWeimob(Integer wmMallStoreId, List<Integer> storeIdList, Integer enterpriseId);

    /***
     * syncClerkToWeimobTask
     * @Title: syncClerkToWeimobTask
     * @Description:
     * @author zhiwj
     * @param param
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Void>
     * @throws
     */
    ServiceResponse<Void> syncClerkToWeimobTask(String param);

    /**
     * 同步失败的重新同步导购
     * @Title: syncClerkToWeimobOfAdd 
     * @Description:
     * @author guojuxing
     * @param wmMallStoreId
     * @param clerkIds
     * @param enterpriseId 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Void> 
     */
    ServiceResponse<Void> syncClerkToWeimob(Integer wmMallStoreId, String clerkIds, Integer enterpriseId);


    /**
     * 导购增改时同步微盟任务
     * @Title: syncClerkToWeimobWhenModify 
     * @Description: 导购增改时同步微盟任务
     * @author guojuxing
     * @param param 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Void> 
     */
    ServiceResponse<Void> syncClerkToWeimobWhenModify(String param);

    /**
     * 好办查询导购列表信息接口（请求参数：clekIds）
     * @Title: listHaobanClerk
     * @Description:
     * @author zhiwj
     * @param clerkIds
     * @return com.gic.api.base.commons.ServiceResponse<java.util.List<com.gic.store.dto.ClerkDTO>>
     * @throws
     */
    ServiceResponse<List<ClerkDTO>> listHaobanClerk(List<Integer> clerkIds);
    
    /**
     * listHaobanClerk
     * @Title: listHaobanClerk
     * @Description: 
     * @author zhiwj 
     * @param enterpriseIdList
     * @param keyword
     * @param storeInfoIdList
     * @return com.gic.api.base.commons.ServiceResponse<java.util.List<com.gic.store.dto.ClerkDTO>>
     * @throws 
     */
    ServiceResponse<List<ClerkDTO>> listHaobanClerk(List<Integer> enterpriseIdList, String keyword, List<Integer> storeInfoIdList);

    /**
     * listHaobanClerk
     * @Title: listHaobanClerk
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param positionId
     * @return com.gic.api.base.commons.ServiceResponse<java.util.List<com.gic.store.dto.ClerkDTO>>
     * @throws
     */
    ServiceResponse<List<ClerkDTO>> listHaobanClerk(Integer enterpriseId, Integer positionId);
}
