package com.gic.store.service;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.store.dto.StoreBrandDTO;

import java.util.List;

/**
 * @ClassName: StoreBrandApiService
 * @Description: 门店品牌
 * @author zhiwj
 * @date 2019/7/31 14:47
 */
public interface StoreBrandApiService {

    /**
     * 保存或编辑
     * @Title: saveOrUpdateStoreBrand
     * @Description: 保存或编辑
     * @author zhiwj
     * @param storeBrandDTO
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Integer>
     * @throws
     */
    ServiceResponse<Integer> saveOrUpdateStoreBrand(StoreBrandDTO storeBrandDTO);

    /**
     * 查询列表
     * @Title: listStoreBrand
     * @Description: 查询列表
     * @author zhiwj 
     * @param enterpriseId 企业id
     * @param search 品牌name or 品牌code
     * @param pageNum
     * @param pageSize
     * @return com.gic.api.base.commons.ServiceResponse<com.gic.api.base.commons.Page<com.gic.store.dto.StoreBrandDTO>>
     * @throws 
     */
    ServiceResponse<Page<StoreBrandDTO>> listStoreBrand(Integer enterpriseId, String search, Integer pageNum, Integer pageSize);

    /**
     * listAllStoreBrand
     * @Title: listAllStoreBrand
     * @Description:
     * @author zhiwj 
     * @param enterpriseId 企业id
     * @param search 品牌name or 品牌code
     * @return com.gic.api.base.commons.ServiceResponse<java.util.List<com.gic.store.dto.StoreBrandDTO>>
     * @throws
     */
    ServiceResponse<List<StoreBrandDTO>> listAllStoreBrand(Integer enterpriseId, String search);
    
    /**
     * 删除全部
     * @Title: deleteAll
     * @Description: 删除全部
     * @author zhiwj 
     * @param enterpriseId
     * @return com.gic.api.base.commons.ServiceResponse
     * @throws
     */
    ServiceResponse<Void> deleteAll(Integer enterpriseId);

    /**
     * 批量删除
     * @Title: deleteByIds
     * @Description: 批量删除
     * @author zhiwj 
     * @param enterpriseId
     * @param ids
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Void>
     * @throws 
     */
    ServiceResponse<Void> deleteByIds(Integer enterpriseId, String ids);

    /**
     * 移动顺序
     * @Title: moveStoreBrand
     * @Description: 移动顺序
     * @author zhiwj
     * @param enterpriseId 
     * @param storeBrandId
     * @param moveType
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Void>
     * @throws 
     */
    ServiceResponse<Void> moveStoreBrand(Integer enterpriseId, Integer storeBrandId, Integer moveType);

    /**
     * 设置序号
     * @Title: setStoreBrandSort
     * @Description: 设置序号
     * @author zhiwj 
     * @param enterpriseId
     * @param storeBrandId
     * @param seq
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Void>
     * @throws 
     */
    ServiceResponse<Void> setStoreBrandSort(Integer enterpriseId, Integer storeBrandId, Integer seq);

    /**
     * 查询list
     * @Title: listStoreBrandByIds
     * @Description:
     * @author zhiwj
     * @param brandIdList
     * @return com.gic.api.base.commons.ServiceResponse<java.util.List<com.gic.store.dto.StoreBrandDTO>>
     * @throws
     */
    ServiceResponse<List<StoreBrandDTO>> listStoreBrandByIds(List<Integer> brandIdList);

    /**
     * 查详情
     * @Title: getById
     * @Description:
     * @author zhiwj
     * @param storeBrandId
     * @return com.gic.api.base.commons.ServiceResponse<com.gic.store.dto.StoreBrandDTO>
     * @throws
     */
    ServiceResponse<StoreBrandDTO> getById(Integer storeBrandId);

    /**
     * 更新是否和实施运维平台有关联
     * @Title: updateRelByOperation
     * @Description:
     * @author zhiwj
     * @param storeBrandId
     * @param hasRel
     * @return com.gic.api.base.commons.ServiceResponse<java.lang.Void>
     * @throws
     */
    ServiceResponse<Void> updateRelByOperation(Integer storeBrandId, Integer hasRel);
}
