package com.gic.store.dao.mapper;

import com.gic.store.dto.StoreFieldDTO;
import com.gic.store.entity.TabStoreField;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 
 * @ClassName: TabStoreFieldMapper
 * @Description:  
 * @author zhiwj
 * @date 2020-09-09 18:37
 */
public interface TabStoreFieldMapper {
    /**
     * 根据主键删除
     *
     * @param storeFieldId 主键
     * @return 更新条目数
     */
    int deleteByPrimaryKey(Integer storeFieldId);

    /**
     * 插入一条记录
     *
     * @param record 实体对象
     * @return 更新条目数
     */
    int insert(TabStoreField record);

    /**
     * 动态插入一条记录
     *
     * @param record 实体对象
     * @return 更新条目数
     */
    int insertSelective(TabStoreField record);

    /**
     * 根据主键查询
     *
     * @param storeFieldId 主键
     * @return 实体对象
     */
    TabStoreField selectByPrimaryKey(Integer storeFieldId);

    /**
     * 根据主键动态更新记录
     *
     * @param record 实体对象
     * @return 更新条目数
     */
    int updateByPrimaryKeySelective(TabStoreField record);

    /**
     * 根据主键更新记录
     *
     * @param record 实体对象
     * @return 更新条目数
     */
    int updateByPrimaryKey(TabStoreField record);

    /**
     * 获取下一个排序值
     * @param enterpriseId
     * @param sort
     * @return
     */
    StoreFieldDTO selectNextByEnterpriseIdAndSort(@Param("enterpriseId") Integer enterpriseId, @Param("sort") Double sort);

    /**
     * 获取上一个排序值
     * @param enterpriseId
     * @param sort
     * @return
     */
    StoreFieldDTO selectPrevByStoreFieldIdAndSort(@Param("enterpriseId") Integer enterpriseId, @Param("sort") Double sort);

    /**
     * 查询某字段最小排序值
     * @param enterpriseId
     * @return
     */
    Double getMinSort(@Param("enterpriseId") Integer enterpriseId);

    /**
     * 查询某字段最大排序值
     * @param enterpriseId
     * @return
     */
    Double getMaxSort(@Param("enterpriseId") Integer enterpriseId);

    /**
     * 查询几条连续的记录
     * @param storeFieldId 要除外的id
     * @param start 开始的位置
     * @param size  查询几条条
     * @param enterpriseId
     * @return
     */
    List<StoreFieldDTO> listTwoElementExceptId(@Param("storeFieldId") Integer storeFieldId, @Param("start") int start,
                                                     @Param("size") int size, @Param("enterpriseId") Integer enterpriseId);

    /**
     * 分页查询
     * @Title: listStoreField 
     * @Description:
      * @author guojuxing
     * @param enterpriseId
     * @param search
     * @param storeFieldIdList 
     * @return  java.util.List<com.gic.store.entity.TabStoreField> 
      */
    List<StoreFieldDTO> listStoreField(@Param("enterpriseId") Integer enterpriseId, @Param("search") String search,
                                       @Param("list") List<Integer> storeFieldIdList);

    /**
     * deleteAll
     * @Title: deleteAll
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @return int
     * @throws
     */
    int deleteAll(@Param("enterpriseId") Integer enterpriseId);

    /**
     * deleteBatch
     * @Title: deleteBatch
     * @Description:
     * @author zhiwj
     * @param storeFieldIds
     * @return int
     * @throws
     */
    int deleteBatch(@Param("storeFieldIds") List<Integer> storeFieldIds);

    /**
     * 查询
     * @param storeFieldIds
     * @return
     */
    List<TabStoreField> listByBatchId(@Param("storeFieldIds") List<Integer> storeFieldIds);

    /**
     * isRepeatCode
     * @Title: isRepeatCode
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param storeFieldId
     * @param storeFieldCode
     * @return int
     * @throws
     */
    int isRepeatCode(@Param("enterpriseId") Integer enterpriseId, @Param("storeFieldId") Integer storeFieldId,
                     @Param("storeFieldCode") String storeFieldCode);

    /**
     * isRepeatName
     * @Title: isRepeatName
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param storeFieldId
     * @param storeFieldName
     * @return int
     * @throws
     */
    int isRepeatName(@Param("enterpriseId") Integer enterpriseId, @Param("storeFieldId") Integer storeFieldId,
                     @Param("storeFieldName") String storeFieldName);


    /**
     * 根据域ID查询列表数据
     * @param regionId
     * @return
     */
    List<StoreFieldDTO> listStoreFieldByRegionId(@Param("regionId") Integer regionId);


    /**
     * 根据企业ID查询列表数据
     * @param enterpriseId
     * @return
     */
    List<StoreFieldDTO> listStoreFieldByEnterpriseId(@Param("enterpriseId") Integer enterpriseId);

    /**
     * countStoreField
     * @Title: countStoreField
     * @Description:
     * @author zhiwj
 * @param enterpriseId
 * @param regionId
     * @return int
     * @throws
     */
    int countStoreField(@Param("enterpriseId") Integer enterpriseId, @Param("regionId") Integer regionId);

    /**
     * 查询自己域的门店自定义字段
     * @Title: listOwnStoreField 
     * @Description:
      * @author guojuxing
     * @param enterpriseId
     * @param storeFieldIdList 
     * @return  java.util.List<com.gic.store.dto.StoreFieldDTO> 
      */
    List<StoreFieldDTO> listOwnStoreField(@Param("enterpriseId") Integer enterpriseId,@Param("list") List<Integer> storeFieldIdList);
}