package com.gic.store.dao.mapper;

import com.gic.store.dto.StoreDTO;
import com.gic.store.dto.StoreSearchDbDTO;
import com.gic.store.entity.TabStoreInfo;
import com.github.pagehelper.Page;
import org.apache.ibatis.annotations.Param;

import java.util.List;
/**
 * 
 * @ClassName: TabStoreInfoMapper
 * @Description:  
 * @author zhiwj
 * @date 2020-09-09 18:38
 */
public interface TabStoreInfoMapper {
    /**
     * 根据主键删除
     *
     * @param storeId 主键
     * @return 更新条目数
     */
    int deleteByPrimaryKey(Integer storeId);

    /**
     * 插入一条记录
     *
     * @param record 实体对象
     * @return 更新条目数
     */
    int insert(TabStoreInfo record);

    /**
     * 动态插入一条记录
     *
     * @param record 实体对象
     * @return 更新条目数
     */
    int insertSelective(TabStoreInfo record);

    /**
     * 根据主键查询
     *
     * @param storeId 主键
     * @return 实体对象
     */
    TabStoreInfo selectByPrimaryKey(Integer storeId);

    /**
     * 根据主键动态更新记录
     *
     * @param record 实体对象
     * @return 更新条目数
     */
    int updateByPrimaryKeySelective(TabStoreInfo record);

    /**
     * 根据主键更新记录
     *
     * @param record 实体对象
     * @return 更新条目数
     */
    int updateByPrimaryKey(TabStoreInfo record);

    /**
     * 如果id不为null， 会查询storeId不为传入参数的数据；如果id为null， 会略过
     *
     * @param storeDTO
     * @return
     */
    Integer countBySelective(@Param("storeDTO") StoreDTO storeDTO);

    /**
     * countByBrandId
     * @Title: countByBrandId
     * @Description:
     * @author zhiwj
 * @param brandId
     * @return java.lang.Integer
     * @throws
     */
    Integer countByBrandId(@Param("brandId") Integer brandId);

    /**
     * listStore
     * @Title: listStore
     * @Description:
     * @author zhiwj
     * @param store
     * @return com.github.pagehelper.Page<com.gic.store.dto.StoreDTO>
     * @throws
     */
    Page<StoreDTO> listStore(@Param("store") StoreSearchDbDTO store);

    /**
     * updateAllStoreStatus
     * @Title: updateAllStoreStatus
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param value
     * @return int
     * @throws
     */
    int updateAllStoreStatus(@Param("enterpriseId") Integer enterpriseId, @Param("value") int value);

    /**
     * updateStoreStatusBystoreInfoIds
     * @Title: updateStoreStatusBystoreInfoIds
     * @Description:
     * @author zhiwj
     * @param value
     * @param storeIdList
     * @return int
     * @throws
     */
    int updateStoreStatusBystoreInfoIds( @Param("value") int value, @Param("storeInfoIdList") List<Integer> storeIdList);

    /**
     * updateAllStoreConactsPhone
     * @Title: updateAllStoreConactsPhone
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param value
     * @return int
     * @throws
     */
    int updateAllStoreConactsPhone(@Param("enterpriseId") Integer enterpriseId, @Param("value") String value);

    /**
     * updateStoreConactsPhoneBystoreInfoIds
     * @Title: updateStoreConactsPhoneBystoreInfoIds
     * @Description:
     * @author zhiwj
     * @param value
     * @param storeInfoIdList
     * @return int
     * @throws
     */
    int updateStoreConactsPhoneBystoreInfoIds(@Param("value") String value, @Param("storeInfoIdList") List<Integer> storeInfoIdList);

    /**
     * updateAllStoreBrand
     * @Title: updateAllStoreBrand
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param value
     * @return int
     * @throws
     */
    int updateAllStoreBrand(@Param("enterpriseId") Integer enterpriseId, @Param("value") String value);

    /**
     * updateStoreBrandBystoreInfoIds
     * @Title: updateStoreBrandBystoreInfoIds
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param value
     * @param storeInfoIdList
     * @return int
     * @throws
     */
    int updateStoreBrandBystoreInfoIds(@Param("enterpriseId") Integer enterpriseId, @Param("value") String value, @Param("storeInfoIdList") List<Integer> storeInfoIdList);

    /**
     * getByStoreNameAndStoreCode
     * @Title: getByStoreNameAndStoreCode
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param regionId
     * @param storeName
     * @param storeCode
     * @return com.gic.store.dto.StoreDTO
     * @throws
     */
    StoreDTO getByStoreNameAndStoreCode(@Param("enterpriseId") Integer enterpriseId, @Param("regionId") Integer regionId, @Param("storeName") String storeName, @Param("storeCode") String storeCode);

    /**
     * listAllstoreInfoId
     * @Title: listAllstoreInfoId
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @return java.util.List<java.lang.Integer>
     * @throws
     */
    List<Integer> listAllstoreInfoId(@Param("enterpriseId") Integer enterpriseId);

    /**
     * listAllstoreId
     * @Title: listAllstoreId
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @return java.util.List<java.lang.Integer>
     * @throws
     */
    List<Integer> listAllstoreId(@Param("enterpriseId") Integer enterpriseId);

    /**
     * getByStore
     * @Title: getByStore
     * @Description:
     * @author zhiwj
     * @param store
     * @return com.gic.store.entity.TabStoreInfo
     * @throws
     */
    TabStoreInfo getByStore(@Param("store") StoreDTO store);

    /**
     * getDTOByStore
     * @Title: getDTOByStore
     * @Description:
     * @author zhiwj
     * @param store
     * @return com.gic.store.dto.StoreDTO
     * @throws
     */
    StoreDTO getDtoByStore(@Param("store") StoreDTO store);

    /**
     * getStoreOwnerByStoreInfoId
     * @Title: getStoreOwnerByStoreInfoId
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param storeInfoId
     * @return java.lang.Integer
     * @throws
     */
    Integer getStoreOwnerByStoreInfoId(@Param("enterpriseId") Integer enterpriseId, @Param("storeInfoId") Integer storeInfoId);

    /**
     * getStoreIdByStoreInfoId
     * @Title: getStoreIdByStoreInfoId
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param storeInfoId
     * @return java.lang.Integer
     * @throws
     */
    Integer getStoreIdByStoreInfoId(@Param("enterpriseId") Integer enterpriseId, @Param("storeInfoId") Integer storeInfoId);
}