package com.gic.store.dao.mapper;

import com.gic.store.entity.TabStore;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 
 * @ClassName: TabStoreMapper
 * @Description:  
 * @author zhiwj
 * @date 2020-09-09 18:38
 */
public interface TabStoreMapper {
    /**
     * 根据主键删除
     *
     * @param storeId 主键
     * @return 更新条目数
     */
    int deleteByPrimaryKey(Integer storeId);

    /**
     * 插入一条记录
     *
     * @param record 实体对象
     * @return 更新条目数
     */
    int insert(TabStore record);

    /**
     * 动态插入一条记录
     *
     * @param record 实体对象
     * @return 更新条目数
     */
    int insertSelective(TabStore record);

    /**
     * 根据主键查询
     *
     * @param storeId 主键
     * @return 实体对象
     */
    TabStore selectByPrimaryKey(Integer storeId);

    /**
     * 根据主键动态更新记录
     *
     * @param record 实体对象
     * @return 更新条目数
     */
    int updateByPrimaryKeySelective(TabStore record);

    /**
     * 根据主键更新记录
     *
     * @param record 实体对象
     * @return 更新条目数
     */
    int updateByPrimaryKey(TabStore record);

    /**
     * updateGroupId
     * @Title: updateGroupId
     * @Description:
     * @author zhiwj
     * @param oldStoreGroupIds
     * @param newStoreGroupId
     * @return java.lang.Integer
     * @throws
     */
    Integer updateGroupId(@Param("oldStoreGroupId") Integer oldStoreGroupIds, @Param("newStoreGroupId") Integer newStoreGroupId);

    /**
     * updateAllStoreGroup
     * @Title: updateAllStoreGroup
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param value
     * @return int
     * @throws
     */
    int updateAllStoreGroup(@Param("enterpriseId") Integer enterpriseId, @Param("value") Integer value);

    /**
     * updateStoreGroupBystoreInfoIds
     * @Title: updateStoreGroupBystoreInfoIds
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param value
     * @param storeInfoIdList
     * @return int
     * @throws
     */
    int updateStoreGroupBystoreInfoIds(@Param("enterpriseId") Integer enterpriseId,
                                       @Param("value") Integer value,
                                       @Param("storeInfoIdList") List<Integer> storeInfoIdList);

    /**
     * getStoreNoStatus
     * @Title: getStoreNoStatus
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param storeInfoId
     * @return java.util.List<com.gic.store.entity.TabStore>
     * @throws
     */
    List<TabStore> getStoreNoStatus(@Param("enterpriseId") Integer enterpriseId, @Param("storeInfoId") Integer storeInfoId);

    /**
     * listStoreIdByFromEnterpriseId
     * @Title: listStoreIdByFromEnterpriseId
     * @Description:
     * @author zhiwj
     * @param fromEnterpriseId
     * @return java.util.List<java.lang.Integer>
     * @throws
     */
    List<Integer> listStoreIdByFromEnterpriseId(@Param("fromEnterpriseId") Integer fromEnterpriseId);

    /**
     * cancelAuthStore
     * @Title: cancelAuthStore
     * @Description:
     * @author zhiwj
     * @param storeInfoIdList
     * @param toEnterpriseId
     * @return int
     * @throws
     */
    int cancelAuthStore(@Param("storeInfoIdList") List<Integer> storeInfoIdList, @Param("toEnterpriseId") Integer toEnterpriseId);

    /**
     * cancelAuthStoreAll
     * @Title: cancelAuthStoreAll
     * @Description:
     * @author zhiwj
     * @param fromEnterpriseId
     * @param toEnterpriseId
     * @return int
     * @throws
     */
    int cancelAuthStoreAll(@Param("fromEnterpriseId") Integer fromEnterpriseId,
                        @Param("toEnterpriseId") Integer toEnterpriseId);

    /**
     * listStoreInfoIdByStoreIds
     * @Title: listStoreInfoIdByStoreIds
     * @Description:
     * @author zhiwj
     * @param ids
     * @param enterpriseId
     * @return java.util.List<java.lang.Integer>
     * @throws
     */
    List<Integer> listStoreInfoIdByStoreIds(@Param("ids") List<Integer> ids, @Param("enterpriseId") Integer enterpriseId);

    /**
     * listStoredByStoreInfoList
     * @Title: listStoredByStoreInfoList
     * @Description:
     * @author zhiwj
     * @param storeInfoIdList
     * @param enterpriseId
     * @return java.util.List<java.lang.Integer>
     * @throws
     */
    List<Integer> listStoredByStoreInfoList(@Param("ids") List<Integer> storeInfoIdList, @Param("enterpriseId") Integer enterpriseId);

    /**
     * listAllCityId
     * @Title: listAllCityId
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param storeBrandId
     * @return java.util.List<java.lang.String>
     * @throws
     */
    List<String> listAllCityId(@Param("enterpriseId") Integer enterpriseId, @Param("storeBrandId") Integer storeBrandId);

    /**
     * checkExistStore
     * @Title: checkExistStore
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @return java.lang.Integer
     * @throws
     */
    Integer checkExistStore(@Param("enterpriseId") Integer enterpriseId);

    /**
     * refreshStoreIndex
     * @Title: refreshStoreIndex
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @return int
     * @throws
     */
    int refreshStoreIndex(@Param("enterpriseId") Integer enterpriseId);

    /**
     * refreshStoreIndexByStoreGroup
     * @Title: refreshStoreIndexByStoreGroup
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param storeGroupId
     * @return int
     * @throws
     */
    int refreshStoreIndexByStoreGroup(@Param("enterpriseId") Integer enterpriseId, @Param("storeGroupId") Integer storeGroupId);
}