package com.gic.store.service;

import com.gic.store.dto.StoreGroupDTO;
import com.gic.store.entity.TabStoreGroup;
import com.github.pagehelper.Page;

import java.util.List;

/**
 * 门店分组
 * @ClassName: StoreGroupService   
 * @Description:    
 * @author guojuxing   
 * @date 2019/7/31 1:44 PM  
 */
public interface StoreGroupService {

    /**
    * 根据名称查询分组
    * @Title: getStoreGroupByName 
    * @Description: 
      * @author guojuxing 
    * @param storeGroupName
    * @param enterpriseId 
    * @return  com.gic.store.entity.TabStoreGroup 
      */
    TabStoreGroup getStoreGroupByName(String storeGroupName, Integer enterpriseId);

    /**
     * 拖拽排序
     * @Title: dragSort 
     * @Description: 
      * @author guojuxing 
     * @param storeGroup
     * @param toSortValue 
     * @return  void 
      */
    void dragSort(TabStoreGroup storeGroup, Integer toSortValue);

    /**
     * getStoreGroupById
     * @Title: getStoreGroupById 
     * @Description: 
      * @author guojuxing 
     * @param storeGroupId 
     * @return  com.gic.store.entity.TabStoreGroup 
      */
    TabStoreGroup getStoreGroupById(Integer storeGroupId);

    /**
     * 更新排序值
     * @Title: updateSort 
     * @Description:
      * @author guojuxing
     * @param sort
     * @param storeGroupId 
     * @return  void 
      */
    void updateSort(Integer sort, Integer storeGroupId);

    /**
    * 查询未分组门店  分组
    * @Title: selectUnGroupedStore 
    * @Description:
      * @author guojuxing
    * @param enterpriseId 
    * @return  com.gic.store.entity.TabStoreGroup 
      */
    TabStoreGroup selectUnGroupedStore(Integer enterpriseId);

    /**
     * 根据主键ID查询分组以及子集分组
     * @Title: listStoreGroupAndChildren 
     * @Description:
      * @author guojuxing
     * @param storeGroupId 
     * @return  java.util.List<com.gic.store.entity.TabStoreGroup> 
      */
    List<TabStoreGroup> listStoreGroupAndChildren(Integer storeGroupId);

    /**
     * 分组名称是否重复
     * @Title: isRepeatName 
     * @Description:
      * @author guojuxing
     * @param storeGroupName
     * @param storeGroupId
     * @param enterpriseId 
     * @return  boolean 
      */
    boolean isRepeatName(String storeGroupName, Integer storeGroupId, Integer enterpriseId);

    /**
     * 更新保存
     * @Title: update 
     * @Description:
      * @author guojuxing
     * @param storeGroupDTO 
     * @return  void 
      */
    void update(StoreGroupDTO storeGroupDTO);

    /**
     * 更新保存
     * @Title: update 
     * @Description:
      * @author guojuxing
     * @param tabStoreGroup 
     * @return  void 
      */
    void update(TabStoreGroup tabStoreGroup);

    /**
     * 新增
     * @Title: insert 
     * @Description:
      * @author guojuxing
     * @param storeGroupDTO 
     * @return  int 
      */
    int insert(StoreGroupDTO storeGroupDTO);

    /**
     * 批量更新分组连数据，当修改上级ID时候
     * @Title: updateStoreGroupChainByStoreGroupId 
     * @Description:
      * @author guojuxing
     * @param storeGroupId
     * @param oldStoreGroupParentId
     * @param storeGroupParentId 
     * @return  void 
      */
    void updateStoreGroupChainByStoreGroupId(Integer storeGroupId, Integer oldStoreGroupParentId,
            Integer storeGroupParentId);

    /**
     * getStoreGroupWhenMaxSort
     * @Title: getStoreGroupWhenMaxSort 
     * @Description:
      * @author guojuxing
     * @param enterpriseId
     * @param groupLevel
     * @param sort 
     * @return  com.gic.store.entity.TabStoreGroup 
      */
    TabStoreGroup getStoreGroupWhenMaxSort(Integer enterpriseId, Integer groupLevel, Integer sort);

    /**
     * getStoreGroupWhenMinSort
     * @Title: getStoreGroupWhenMinSort 
     * @Description:
      * @author guojuxing
     * @param enterpriseId
     * @param groupLevel
     * @param sort 
     * @return  com.gic.store.entity.TabStoreGroup 
      */
    TabStoreGroup getStoreGroupWhenMinSort(Integer enterpriseId, Integer groupLevel, Integer sort);

    /**
     * 查询
     * @param groupLevel
     * @param enterpriseId
     * @param storeGroupName
     * @return
     */
    List<TabStoreGroup> listStoreGroup(Integer groupLevel, Integer enterpriseId, String storeGroupName);

    /**
     * 获取最大的排序值
     * @Title: selectStoreGroupMaxSort 
     * @Description:
      * @author guojuxing
     * @param enterpriseId
     * @param groupLevel 
     * @return  int 
      */
    int selectStoreGroupMaxSort(Integer enterpriseId, Integer groupLevel);

    /**
     * 是否是叶子节点
     * @Title: isLeafNode 
     * @Description:
      * @author guojuxing
     * @param storeGroupId 
     * @return  boolean 
      */
    boolean isLeafNode(Integer storeGroupId);

    /**
     * 查询所有门店分组
     * @Title: selectAllStoreGroup 
     * @Description:
      * @author guojuxing
     * @param enterpriseId 
     * @return  com.gic.store.entity.TabStoreGroup 
      */
    TabStoreGroup selectAllStoreGroup(Integer enterpriseId);

    /**
     * listStoreGroupByIds
     * @Title: listStoreGroupByIds
     * @Description:
     * @author zhiwj
     * @param storeGroupIdList
     * @param enterpriseId
     * @param level
     * @return java.util.List<com.gic.store.entity.TabStoreGroup>
     * @throws
     */
    List<TabStoreGroup> listStoreGroupByIds(List<Integer> storeGroupIdList, Integer enterpriseId, Integer level);

    /**
     * pageStoreGroupByIds
     * @Title: pageStoreGroupByIds
     * @Description:
     * @author zhiwj
     * @param storeGroupIdList
     * @param enterpriseId
     * @param parentId
     * @param search
     * @return com.github.pagehelper.Page<com.gic.store.entity.TabStoreGroup>
     * @throws
     */
    Page<TabStoreGroup> pageStoreGroupByIds(List<Integer> storeGroupIdList, Integer enterpriseId, Integer parentId, String search);

    /**
     * listChildrenStoreGroup
     * @Title: listChildrenStoreGroup
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param parentStoreGroupId
     * @return java.util.List<com.gic.store.entity.TabStoreGroup>
     * @throws
     */
    List<TabStoreGroup> listChildrenStoreGroup(Integer enterpriseId, Integer parentStoreGroupId);
}
