package com.gic.store.service;

import com.gic.store.dto.StoreDTO;
import com.gic.store.dto.StoreSearchDbDTO;
import com.gic.store.entity.TabStore;
import com.github.pagehelper.Page;

import java.util.List;

/**
 * @author zhiwj
 * @date 2019/6/27
 */
public interface StoreService {
    /**
     * save
     * @Title: save
     * @Description:
     * @author zhiwj
     * @param storeDTO
     * @return java.lang.Integer
     * @throws
     */
    Integer save(StoreDTO storeDTO);

    /**
     * update
     * @Title: update
     * @Description:
     * @author zhiwj
     * @param storeDTO
     * @return java.lang.Integer
     * @throws
     */
    Integer update(StoreDTO storeDTO);

    /**
     * 该分组下门店的个数
     * countByGroupId
     * @Title: countByGroupId
     * @Description:
     * @author zhiwj
     * @param storeGroupId
     * @return java.lang.Integer
     * @throws
     */
    Integer countByGroupId(Integer storeGroupId);

    /**
     * updateGroupId 修改门店分组
     * @Title: updateGroupId
     * @Description:
     * @author zhiwj
     * @param oldStoreGroupId
     * @param newStoreGroupId
     * @return java.lang.Integer
     * @throws
     */
    Integer updateGroupId(Integer oldStoreGroupId, Integer newStoreGroupId);

    /**
     * getById
     * @Title: getById
     * @Description:
     * @author zhiwj
     * @param storeId
     * @return com.gic.store.dto.StoreDTO
     * @throws
     */
    StoreDTO getById(Integer storeId);

    /**
     * countByBrandId
     * @Title: countByBrandId
     * @Description:
     * @author zhiwj
     * @param brandId
     * @return java.lang.Integer
     * @throws
     */
    Integer countByBrandId(Integer brandId);

    /**
     * 查询如企业下门店代码的个数
     * @param enterpriseId
     * @param storeCode
     * @param storeId  如果id不为null， 会查询storeId不为传入参数的数据；如果id为null， 会略过
     * @return
     */
    Integer countByStoreCode(Integer enterpriseId, String storeCode, Integer storeId);

    /**
     * countByOverflowStatus
     * @Title: countByOverflowStatus
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param overflowStatus
     * @return java.lang.Integer
     * @throws
     */
    Integer countByOverflowStatus(Integer enterpriseId, Integer overflowStatus);

    /**
     * listStore
     * @Title: listStore
     * @Description:
     * @author zhiwj
     * @param storeDTO
     * @param pageNum
     * @param pageSize
     * @return com.github.pagehelper.Page<com.gic.store.dto.StoreDTO>
     * @throws
     */
    Page<StoreDTO> listStore(StoreSearchDbDTO storeDTO, Integer pageNum, Integer pageSize);

    /**
     * checkCompleteStatus
     * @Title: checkCompleteStatus
     * @Description:
     * @author zhiwj
     * @param storeDTO
     * @return java.lang.Integer
     * @throws
     */
    Integer checkCompleteStatus(StoreDTO storeDTO);

    /**
     * updateStoreGroupId
     * @Title: updateStoreGroupId
     * @Description:
     * @author zhiwj
     * @param storeId
     * @param groupId
     * @return int
     * @throws
     */
    int updateStoreGroupId(Integer storeId, Integer groupId);

    /**
     * countByStoreName
     * @Title: countByStoreName
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param storeName
     * @param storeId
     * @return java.lang.Integer
     * @throws
     */
    Integer countByStoreName(Integer enterpriseId, String storeName, Integer storeId);
    /**
     * bulkUpdateStoreStatus
     * @Title: bulkUpdateStoreStatus
     * @Description:
     * @author zhiwj
     * @param storeIds
     * @param enterpriseId
     * @param value
     * @return int
     * @throws
     */
    int bulkUpdateStoreStatus(String storeIds, Integer enterpriseId, String value);

    /**
     * bulkUpdateStoreConactsPhone
     * @Title: bulkUpdateStoreConactsPhone
     * @Description:
     * @author zhiwj
     * @param storeIds
     * @param enterpriseId
     * @param value
     * @return int
     * @throws
     */
    int bulkUpdateStoreConactsPhone(String storeIds, Integer enterpriseId, String value);

    /**
     * bulkUpdateStoreBusinessTime
     * @Title: bulkUpdateStoreBusinessTime
     * @Description:
     * @author zhiwj
     * @param storeIds
     * @param enterpriseId
     * @param value
     * @return int
     * @throws
     */
    int bulkUpdateStoreBusinessTime(String storeIds, Integer enterpriseId, String value);

    /**
     * bulkUpdateStorePhoto
     * @Title: bulkUpdateStorePhoto
     * @Description:
     * @author zhiwj
     * @param storeInfoIds
     * @param enterpriseId
     * @param value
     * @return int
     * @throws
     */
    int bulkUpdateStorePhoto(String storeInfoIds, Integer enterpriseId, String value);

    /**
     * bulkAddStorePhoto
     * @Title: bulkAddStorePhoto
     * @Description:
     * @author zhiwj
     * @param storeIds
     * @param enterpriseId
     * @param value
     * @return int
     * @throws
     */
    int bulkAddStorePhoto(String storeIds, Integer enterpriseId, String value);

    /**
     * bulkUpdateStoreBrands
     * @Title: bulkUpdateStoreBrands
     * @Description:
     * @author zhiwj
     * @param storeIds
     * @param enterpriseId
     * @param value
     * @return int
     * @throws
     */
    int bulkUpdateStoreBrands(String storeIds, Integer enterpriseId, String value);

    /**
     * bulkUpdateStoreGroup
     * @Title: bulkUpdateStoreGroup
     * @Description:
     * @author zhiwj
     * @param storeInfoIds
     * @param enterpriseId
     * @param value
     * @return int
     * @throws
     */
    int bulkUpdateStoreGroup(String storeInfoIds, Integer enterpriseId, Integer value);

    /**
     * getByStoreNameAndStoreCode
     * @Title: getByStoreNameAndStoreCode
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param regionId
     * @param storeName
     * @param storeCode
     * @return com.gic.store.dto.StoreDTO
     * @throws
     */
    StoreDTO getByStoreNameAndStoreCode(Integer enterpriseId, Integer regionId, String storeName, String storeCode);

    /**
     * listAllStoreId
     * @Title: listAllStoreId
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @return java.util.List<java.lang.Integer>
     * @throws
     */
    List<Integer> listAllStoreId(Integer enterpriseId);

    /**
     * listAllStoreInfoId
     * @Title: listAllStoreInfoId
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @return java.util.List<java.lang.Integer>
     * @throws
     */
    List<Integer> listAllStoreInfoId(Integer enterpriseId);

    /**
     * validateStoreCodeIsExist
     * @Title: validateStoreCodeIsExist
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param regionId
     * @param storeCode
     * @param storeId
     * @return boolean
     * @throws
     */
    boolean validateStoreCodeIsExist(Integer enterpriseId, Integer regionId, String storeCode, Integer storeId);

    /**
     * 严重是否门店code重复，返回门店ID
     * @Title: validateStoreCodeIsExist 
     * @Description:
      * @author guojuxing
     * @param enterpriseId
     * @param regionId
     * @param storeCode
     * @return  java.lang.Integer 
      */
    Integer validateStoreCodeIsExist(Integer enterpriseId, Integer regionId, String storeCode);

    /**
     * getStoreByRegionIdAndStoreCode
     * @Title: getStoreByRegionIdAndStoreCode
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param regionId
     * @param storeCode
     * @return com.gic.store.dto.StoreDTO
     * @throws
     */
    StoreDTO getStoreByRegionIdAndStoreCode(Integer enterpriseId, Integer regionId, String storeCode);

    /**
     * validateStoreNameIsExist
     * @Title: validateStoreNameIsExist
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param regionId
     * @param storeName
     * @param storeId
     * @return boolean
     * @throws
     */
    boolean validateStoreNameIsExist(Integer enterpriseId, Integer regionId, String storeName, Integer storeId);

    /**
     * authAddStore
     * @Title: authAddStore
     * @Description:
     * @author zhiwj
     * @param storeDTO
     * @return int
     * @throws
     */
    int authAddStore(StoreDTO storeDTO);

    /**
     * listStoreIdByFromEnterpriseId
     * @Title: listStoreIdByFromEnterpriseId
     * @Description:
     * @author zhiwj
     * @param fromEnterpriseId
     * @return java.util.List<java.lang.Integer>
     * @throws
     */
    List<Integer> listStoreIdByFromEnterpriseId(Integer fromEnterpriseId);

    /**
     * cancelAuthStore
     * @Title: cancelAuthStore
     * @Description:
     * @author zhiwj
     * @param storeInfoIdList
     * @param toEnterpriseId
     * @return int
     * @throws
     */
    int cancelAuthStore(List<Integer> storeInfoIdList, Integer toEnterpriseId);

    /**
     * cancelAuthStoreAll
     * @Title: cancelAuthStoreAll
     * @Description:
     * @author zhiwj
     * @param fromEnterpriseId
     * @param toEnterpriseId
     * @return int
     * @throws
     */
    int cancelAuthStoreAll(Integer fromEnterpriseId, Integer toEnterpriseId);

    /**
     * getStoreOwnerByStoreInfoId
     * @Title: getStoreOwnerByStoreInfoId
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param storeInfoId
     * @return java.lang.Integer
     * @throws
     */
    Integer getStoreOwnerByStoreInfoId(Integer enterpriseId, Integer storeInfoId);

    /**
     * getStoreIdByStoreInfoId
     * @Title: getStoreIdByStoreInfoId
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param storeInfoId
     * @return java.lang.Integer
     * @throws
     */
    Integer getStoreIdByStoreInfoId(Integer enterpriseId, Integer storeInfoId);

    /**
     * listStoreInfoIdByStoreIds
     * @Title: listStoreInfoIdByStoreIds
     * @Description:
     * @author zhiwj
     * @param storeIds
     * @param enterpriseId
     * @return java.lang.String
     * @throws
     */
    String listStoreInfoIdByStoreIds(String storeIds, Integer enterpriseId);

    /**
     * listStoredByStoreInfoList
     * @Title: listStoredByStoreInfoList
     * @Description:
     * @author zhiwj
     * @param storeInfoIdList
     * @param enterpriseId
     * @return java.util.List<java.lang.Integer>
     * @throws
     */
    List<Integer> listStoredByStoreInfoList(List<Integer> storeInfoIdList, Integer enterpriseId);

    /**
     * listAllCityId 查询企业下所有城市id，门店数量从多到少排序
     * @Title: listAllCityId
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param storeBrandId
     * @return java.util.List<java.lang.String>
     * @throws
     */
    List<String> listAllCityId(Integer enterpriseId, Integer storeBrandId);

    /**
     * updateStore
     * @Title: updateStore
     * @Description:
     * @author zhiwj
     * @param storeDTO
     * @return void
     * @throws
     */
    void updateStore(StoreDTO storeDTO);

    /**
     * getByStoreCodeAndRegionId
     * @Title: getByStoreCodeAndRegionId
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param regionId
     * @param storeCode
     * @return com.gic.store.entity.TabStore
     * @throws
     */
    TabStore getByStoreCodeAndRegionId(Integer enterpriseId, Integer regionId, String storeCode);

    /**
     * checkExistStore
     * @Title: checkExistStore
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @return java.lang.Boolean
     * @throws
     */
    Boolean checkExistStore(Integer enterpriseId);

    /**
     * refreshStoreIndex
     * @Title: refreshStoreIndex
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @return int
     * @throws
     */
    int refreshStoreIndex(Integer enterpriseId);

    /**
     * refreshStoreIndex
     * @Title: refreshStoreIndex
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param storeGroupId
     * @return int
     * @throws
     */
    int refreshStoreIndex(Integer enterpriseId, Integer storeGroupId);
}
