package com.gic.store.service.impl;

import com.gic.commons.util.GlobalInfo;
import com.gic.store.dao.mapper.TabStoreBrandMapper;
import com.gic.store.dto.StoreBrandDTO;
import com.gic.store.entity.TabStoreBrand;
import com.gic.store.service.StoreBrandService;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author zhiwj
 * @date 2019/6/26
 */
@Service
public class StoreBrandServiceImpl implements StoreBrandService {

    @Autowired
    private TabStoreBrandMapper tabStoreBrandMapper;

    @Override
    public Integer save(StoreBrandDTO copy) {
        TabStoreBrand storeBrand = new TabStoreBrand();
        storeBrand.setStoreBrandCode(copy.getStoreBrandCode());
        storeBrand.setStoreBrandName(copy.getStoreBrandName());
        storeBrand.setStoreBrandCategoryCode(copy.getStoreBrandCategoryCode());
        storeBrand.setStoreBrandCategory(copy.getStoreBrandCategory());
        storeBrand.setEnterpriseId(copy.getEnterpriseId());
        storeBrand.setStatus(GlobalInfo.DATA_STATUS_NORMAL);
        storeBrand.setCreateTime(new Date());
        storeBrand.setHasRel(GlobalInfo.DATA_STATUS_DELETE);

        Double sort = tabStoreBrandMapper.getMinSort(copy.getEnterpriseId());
        storeBrand.setSort(sort == null ? 1d : sort - 1d);
        tabStoreBrandMapper.insertSelective(storeBrand);
        return storeBrand.getStoreBrandId();
    }

    @Override
    public Integer update(StoreBrandDTO copy) {
        TabStoreBrand storeBrand = new TabStoreBrand();
        storeBrand.setStoreBrandId(copy.getStoreBrandId());
        storeBrand.setStoreBrandCode(copy.getStoreBrandCode());
        storeBrand.setStoreBrandName(copy.getStoreBrandName());
        storeBrand.setStoreBrandCategoryCode(copy.getStoreBrandCategoryCode());
        storeBrand.setStoreBrandCategory(copy.getStoreBrandCategory());
        return tabStoreBrandMapper.updateByPrimaryKeySelective(storeBrand);
    }

    @Override
    public int countByStoreBrandCode(Integer enterpriseId, String storeBrandCode, Integer storeBrandId) {
        return tabStoreBrandMapper.countBySelective(enterpriseId, storeBrandCode, null, storeBrandId);
    }

    @Override
    public int countByStoreBrandName(Integer enterpriseId, String storeBrandName, Integer storeBrandId) {
        return tabStoreBrandMapper.countBySelective(enterpriseId, null, storeBrandName, storeBrandId);
    }

    @Override
    public TabStoreBrand getByStoreBrandName(Integer enterpriseId, String storeBrandName) {
        return tabStoreBrandMapper.getByStoreBrandName(enterpriseId, storeBrandName);
    }

    @Override
    public Page<TabStoreBrand> listStoreBrand(Integer enterpriseId, String search, Integer pageNum, Integer pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<TabStoreBrand> storeBrandList = tabStoreBrandMapper.listStoreBrand(enterpriseId, search);
        return (Page<TabStoreBrand>) storeBrandList;
    }

    @Override
    public List<TabStoreBrand> listAllStoreBrand(Integer enterpriseId, String search) {
        return tabStoreBrandMapper.listStoreBrand(enterpriseId, search);
    }

    @Override
    public void sortMoveUp(Integer enterpriseId, Integer storeBrandId) {
        TabStoreBrand tabStoreBrand = tabStoreBrandMapper.selectByPrimaryKey(storeBrandId);
        TabStoreBrand prevStoreBrand = tabStoreBrandMapper.getPrevSort(enterpriseId, tabStoreBrand.getSort());
        swapSort(tabStoreBrand, prevStoreBrand);
    }

    @Override
    public void sortMoveDown(Integer enterpriseId, Integer storeBrandId) {
        TabStoreBrand tabStoreBrand = tabStoreBrandMapper.selectByPrimaryKey(storeBrandId);
        TabStoreBrand nextStoreBrand = tabStoreBrandMapper.getNextSort(enterpriseId, tabStoreBrand.getSort());
        swapSort(tabStoreBrand, nextStoreBrand);
    }

    private void swapSort(TabStoreBrand tabStoreBrand, TabStoreBrand prevStoreBrand) {
        if (prevStoreBrand != null) {
            Double temp = tabStoreBrand.getSort();
            tabStoreBrand.setSort(prevStoreBrand.getSort());
            prevStoreBrand.setSort(temp);
            tabStoreBrandMapper.updateByPrimaryKeySelective(tabStoreBrand);
            tabStoreBrandMapper.updateByPrimaryKeySelective(prevStoreBrand);
        }
    }

    @Override
    public void sortTopping(Integer enterpriseId, Integer storeBrandId) {
        Double sort = tabStoreBrandMapper.getMinSort(enterpriseId);
        TabStoreBrand tabStoreBrand = new TabStoreBrand();
        tabStoreBrand.setStoreBrandId(storeBrandId);
        tabStoreBrand.setSort(sort - 1d);
        tabStoreBrandMapper.updateByPrimaryKeySelective(tabStoreBrand);
    }

    @Override
    public void sortBottom(Integer enterpriseId, Integer storeBrandId) {
        Double sort = tabStoreBrandMapper.getMaxSort(enterpriseId);
        if (sort != null) {
            TabStoreBrand tabStoreBrand = new TabStoreBrand();
            tabStoreBrand.setStoreBrandId(storeBrandId);
            tabStoreBrand.setSort(sort + 1d);
            tabStoreBrandMapper.updateByPrimaryKeySelective(tabStoreBrand);
        }
    }

    @Override
    public void setStoreBrandSort(Integer enterpriseId, Integer storeBrandId, Integer seq) {
        if (seq <= 1) {
            // 相当于置顶
            sortTopping(enterpriseId, storeBrandId);
        } else {
            int start = seq - 2;
            int size = 2;

            List<TabStoreBrand> list = tabStoreBrandMapper.listTwoElementExceptId(enterpriseId, start, size, storeBrandId);
            if (CollectionUtils.isEmpty(list)) {
                // 置底
                sortBottom(enterpriseId, storeBrandId);
            } else {
                Double sort;
                if (list.size() == 1) {
                    // 置底
                    sort = list.get(0).getSort() + 1d;
                } else {
                    sort = (list.get(0).getSort() + list.get(1).getSort()) / 2d;
                }
                TabStoreBrand tabStoreBrand = new TabStoreBrand();
                tabStoreBrand.setStoreBrandId(storeBrandId);
                tabStoreBrand.setSort(sort);
                tabStoreBrandMapper.updateByPrimaryKeySelective(tabStoreBrand);
            }
        }
    }

    @Override
    public Integer deleteByIds(Integer enterpriseId, List<Integer> delList) {
        if (CollectionUtils.isNotEmpty(delList)) {
            return tabStoreBrandMapper.deleteByIds(delList);
        }
        return 0;
    }

    @Override
    public List<TabStoreBrand> listStoreBrandByIds(String brandIds) {
        if (StringUtils.isBlank(brandIds)) {
            return null;
        }
        List<String> idStrList = Arrays.asList(brandIds.split(","));
        if (CollectionUtils.isNotEmpty(idStrList)) {
            List<Integer> idList = idStrList.stream().map(Integer::parseInt).collect(Collectors.toList());
            return tabStoreBrandMapper.listStoreBrandByIds(idList);
        }
        return null;
    }

    @Override
    public List<TabStoreBrand> listStoreBrandByIds(List<Integer> brandIdList) {
        if (CollectionUtils.isNotEmpty(brandIdList)) {
            return tabStoreBrandMapper.listStoreBrandByIds(brandIdList);
        }
        return null;
    }

    @Override
    public TabStoreBrand getById(Integer storeBrandId) {
        return tabStoreBrandMapper.selectByPrimaryKey(storeBrandId);
    }

    @Override
    public int updateRelByOperation(Integer storeBrandId, Integer hasRel) {
        TabStoreBrand tabStoreBrand = new TabStoreBrand();
        tabStoreBrand.setStoreBrandId(storeBrandId);
        tabStoreBrand.setHasRel(hasRel);
        return tabStoreBrandMapper.updateByPrimaryKeySelective(tabStoreBrand);
    }
}
