package com.gic.store.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.util.GlobalInfo;
import com.gic.store.constant.Constants;
import com.gic.store.constant.StoreOwnTypeEnum;
import com.gic.store.dao.mapper.TabStoreBusinessTimeMapper;
import com.gic.store.dao.mapper.TabStoreInfoMapper;
import com.gic.store.dao.mapper.TabStoreMapper;
import com.gic.store.dao.mapper.TabStorePhotoMapper;
import com.gic.store.dto.StoreDTO;
import com.gic.store.dto.StoreExtendDTO;
import com.gic.store.dto.StoreSearchDbDTO;
import com.gic.store.entity.TabStore;
import com.gic.store.entity.TabStoreField;
import com.gic.store.entity.TabStoreInfo;
import com.gic.store.service.StoreFieldService;
import com.gic.store.service.StoreService;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * @author zhiwj
 * @date 2019/6/27
 */
@Service
public class StoreServiceImpl implements StoreService {
    private static Logger logger = LogManager.getLogger(StoreServiceImpl.class);

    @Autowired
    TabStoreInfoMapper tabStoreInfoMapper;
    @Autowired
    TabStoreBusinessTimeMapper tabStoreBusinessTimeMapper;
    @Autowired
    TabStorePhotoMapper tabStorePhotoMapper;
    @Autowired
    private TabStoreMapper tabStoreMapper;
    @Autowired
    private StoreFieldService storeFieldService;

    @Override
    public Integer save(StoreDTO copy) {
        TabStoreInfo tabStoreInfo = new TabStoreInfo();
        tabStoreInfo.setStoreInfoId(copy.getStoreInfoId());
        tabStoreInfo.setStoreName(copy.getStoreName());
        tabStoreInfo.setStoreCode(copy.getStoreCode());
        tabStoreInfo.setRegionId(copy.getRegionId());
        tabStoreInfo.setConactsPhone(copy.getConactsPhone());
        tabStoreInfo.setAddress(copy.getAddress());
        tabStoreInfo.setBrandIds(copy.getBrandIds());
        tabStoreInfo.setProvinceId(copy.getProvinceId());
        tabStoreInfo.setCityId(copy.getCityId());
        tabStoreInfo.setAreaId(copy.getAreaId());
        tabStoreInfo.setProvinces(copy.getProvinces());
        tabStoreInfo.setLongitude(copy.getLongitude());
        tabStoreInfo.setLatitude(copy.getLatitude());
        tabStoreInfo.setCompleteStatus(copy.getCompleteStatus());
        // 这里要判断一下总量
        Integer count = this.countByStoreName(copy.getEnterpriseId(), "", null);
        if(count >= copy.getLicense()){
            tabStoreInfo.setOverflowStatus(1);
        }else {
            tabStoreInfo.setOverflowStatus(0);
        }
        tabStoreInfo.setStatus(copy.getStatus());
        tabStoreInfo.setErpStatus(copy.getErpStatus());
        tabStoreInfo.setStoreType(copy.getStoreType());
        tabStoreInfo.setCreateType(copy.getCreateType());
        tabStoreInfo.setCreateTime(new Date());
        tabStoreInfo.setEnterpriseId(copy.getEnterpriseId());
        tabStoreInfoMapper.insertSelective(tabStoreInfo);
        TabStore store = new TabStore();
        store.setEnterpriseId(copy.getEnterpriseId());
        store.setCreateTime(new Date());
        store.setUpdateTime(new Date());
        store.setOwnType(StoreOwnTypeEnum.OWNER.getCode());
        store.setStatus(com.gic.enterprise.constants.Constants.NORMAL_STATUS);
        store.setStoreGroupId(copy.getStoreGroupId());
        store.setStoreInfoId(tabStoreInfo.getStoreInfoId());
        store.setFromEnterpriseId(copy.getFromEnterpriseId());
        this.tabStoreMapper.insertSelective(store);
        copy.setStoreId(store.getStoreId());
        copy.setStoreInfoId(store.getStoreInfoId());
        return store.getStoreId();
    }

    @Override
    public Integer update(StoreDTO copy) {
        TabStoreInfo tabStoreInfo = new TabStoreInfo();
        tabStoreInfo.setStoreInfoId(copy.getStoreInfoId());
        tabStoreInfo.setStoreName(copy.getStoreName());
        tabStoreInfo.setStoreCode(copy.getStoreCode());
        tabStoreInfo.setRegionId(copy.getRegionId());
        tabStoreInfo.setConactsPhone(copy.getConactsPhone());
        tabStoreInfo.setAddress(copy.getAddress());
        tabStoreInfo.setBrandIds(copy.getBrandIds());
        tabStoreInfo.setProvinceId(copy.getProvinceId());
        tabStoreInfo.setCityId(copy.getCityId());
        tabStoreInfo.setAreaId(copy.getAreaId());
        tabStoreInfo.setProvinces(copy.getProvinces());
        tabStoreInfo.setLongitude(copy.getLongitude());
        tabStoreInfo.setLatitude(copy.getLatitude());
        tabStoreInfo.setStatus(copy.getStatus());
        tabStoreInfo.setErpStatus(copy.getErpStatus());
        tabStoreInfo.setStoreType(copy.getStoreType());
        tabStoreInfo.setCompleteStatus(copy.getCompleteStatus());
        tabStoreInfo.setIndexId(copy.getIndexId());
        tabStoreInfo.setOverflowStatus(copy.getOverflowStatus());

        TabStore store = new TabStore();
        store.setEnterpriseId(copy.getEnterpriseId());
        store.setOwnType(StoreOwnTypeEnum.OWNER.getCode());
        store.setStatus(com.gic.enterprise.constants.Constants.NORMAL_STATUS);
        store.setStoreGroupId(copy.getStoreGroupId());
        store.setStoreInfoId(tabStoreInfo.getStoreInfoId());
        store.setStoreId(copy.getStoreId());
        store.setFromEnterpriseId(copy.getFromEnterpriseId());
        this.tabStoreMapper.updateByPrimaryKeySelective(store);
        return tabStoreInfoMapper.updateByPrimaryKeySelective(tabStoreInfo);
    }

    @Override
    public Integer countByGroupId(Integer storeGroupId) {
        StoreDTO storeDTO = new StoreDTO();
        storeDTO.setStoreGroupId(storeGroupId);
        return tabStoreInfoMapper.countBySelective(storeDTO);
    }

    @Override
    public Integer updateGroupId(Integer oldStoreGroupId, Integer newStoreGroupId) {
        return this.tabStoreMapper.updateGroupId(oldStoreGroupId, newStoreGroupId);
    }

    @Override
    public StoreDTO getById(Integer storeId) {
        TabStore tabStore = this.tabStoreMapper.selectByPrimaryKey(storeId);
        if(tabStore != null){
            TabStoreInfo tabStoreInfo = tabStoreInfoMapper.selectByPrimaryKey(tabStore.getStoreInfoId());
            StoreDTO storeDTO = EntityUtil.changeEntityByJSON(StoreDTO.class, tabStoreInfo);
            storeDTO.setEnterpriseId(tabStore.getEnterpriseId());
            storeDTO.setStoreGroupId(tabStore.getStoreGroupId());
            storeDTO.setStoreId(tabStore.getStoreId());
            storeDTO.setOwnType(tabStore.getOwnType());
            storeDTO.setFromEnterpriseId(tabStore.getFromEnterpriseId());
            storeDTO.setScore(tabStore.getScore());
            storeDTO.setEvaluateCount(tabStore.getEvaluateCount());
            return storeDTO;
        }
        return null;
    }

    @Override
    public Integer countByBrandId(Integer brandId) {
        return tabStoreInfoMapper.countByBrandId(brandId);
    }

    @Override
    public Integer countByStoreCode(Integer enterpriseId, String storeCode, Integer storeId) {
        StoreDTO store = new StoreDTO();
        store.setEnterpriseId(enterpriseId);
        store.setStoreCode(storeCode);
        store.setStoreInfoId(storeId);
        return tabStoreInfoMapper.countBySelective(store);
    }

    @Override
    public Integer countByOverflowStatus(Integer enterpriseId, Integer overflowStatus) {
        StoreDTO store = new StoreDTO();
        store.setEnterpriseId(enterpriseId);
        store.setOverflowStatus(overflowStatus);
        return tabStoreInfoMapper.countBySelective(store);
    }

    @Override
    public Page<StoreDTO> listStore(StoreSearchDbDTO storeDTO, Integer pageNum, Integer pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        return tabStoreInfoMapper.listStore(storeDTO);
    }

    @Override
    public Integer checkCompleteStatus(StoreDTO storeDTO) {
        List<StoreExtendDTO> storeExtendList = storeDTO.getStoreExtendList();
        if (CollectionUtils.isNotEmpty(storeExtendList)) {
            for (StoreExtendDTO storeExtendDTO : storeExtendList) {
                TabStoreField field = storeFieldService.getStoreFieldById(storeExtendDTO.getStoreFieldId());
                if (field != null) {
                    if (StringUtils.isNotBlank(field.getStoreFieldDetail()) && field.getStoreFieldDetail().contains("\"isMust\":1") && StringUtils.isBlank(storeExtendDTO.getValue())) {
                        return GlobalInfo.DATA_STATUS_DELETE;
                    }
                }
            }
        }
        return StringUtils.isNotBlank(storeDTO.getStoreName()) &&
                storeDTO.getRegionId() != null &&
                StringUtils.isNotBlank(storeDTO.getStoreCode()) &&
                CollectionUtils.isNotEmpty(storeDTO.getPhotoList()) &&
                storeDTO.getStoreType() != null &&
                storeDTO.getErpStatus() != null &&
                StringUtils.isNotBlank(storeDTO.getConactsPhone()) &&
                CollectionUtils.isNotEmpty(storeDTO.getBusinessTimeList()) &&
                StringUtils.isNotBlank(storeDTO.getBusinessTimeList().get(0).getWeekday()) &&
                storeDTO.getStoreGroupId() != null &&
                StringUtils.isNotBlank(storeDTO.getBrandIds()) &&
                StringUtils.isNotBlank(storeDTO.getProvinces()) &&
                StringUtils.isNotBlank(storeDTO.getLongitude()) &&
                StringUtils.isNotBlank(storeDTO.getLatitude()) &&
                StringUtils.isNotBlank(storeDTO.getAddress())
                ? GlobalInfo.DATA_STATUS_NORMAL
                : GlobalInfo.DATA_STATUS_DELETE
                ;
    }

    @Override
    public int updateStoreGroupId(Integer storeId, Integer groupId) {
        TabStore store = new TabStore();
        store.setStoreId(storeId);
        store.setStoreGroupId(groupId);
        return this.tabStoreMapper.updateByPrimaryKeySelective(store);
    }

    @Override
    public Integer countByStoreName(Integer enterpriseId, String storeName, Integer storeId) {
        StoreDTO store = new StoreDTO();
        store.setEnterpriseId(enterpriseId);
        store.setStoreName(storeName);
        store.setStoreInfoId(storeId);
        store.setOverflowStatus(0);
        return tabStoreInfoMapper.countBySelective(store);
    }

    @Override
    public int bulkUpdateStoreStatus(String storeInfoIds, Integer enterpriseId, String value) {
        if (Constants.ALL.equals(storeInfoIds)) {
            return this.tabStoreInfoMapper.updateAllStoreStatus(enterpriseId, Integer.valueOf(value));
        }
        String[] storeInfoIdArr = storeInfoIds.split(",");
        List<Integer> list = new ArrayList<>();
        for (String s : storeInfoIdArr) {
            list.add(Integer.valueOf(s));
        }
        return this.tabStoreInfoMapper.updateStoreStatusBystoreInfoIds(Integer.valueOf(value), list);
    }

    @Override
    public int bulkUpdateStoreConactsPhone(String storeIds, Integer enterpriseId, String value) {
        if (Constants.ALL.equals(storeIds)) {
            return this.tabStoreInfoMapper.updateAllStoreConactsPhone(enterpriseId, value);
        }
        String[] storeInfoIdArr = storeIds.split(",");
        List<Integer> list = new ArrayList<>();
        for (String s : storeInfoIdArr) {
            list.add(Integer.valueOf(s));
        }
        return this.tabStoreInfoMapper.updateStoreConactsPhoneBystoreInfoIds(value, list);
    }

    @Override
    public int bulkUpdateStoreBusinessTime(String storeInfoIds, Integer enterpriseId, String value) {
        try {
            JSONArray array = JSON.parseArray(value);
            SimpleDateFormat simpleDateFormat = new SimpleDateFormat("HH:mm");
            List<Integer> list = new ArrayList<>();
            if (Constants.ALL.equals(storeInfoIds)) {
                this.tabStoreBusinessTimeMapper.deleteAllByEnterpriseId(enterpriseId);
            } else {
                String[] storeInfoIdArr = storeInfoIds.split(",");
                for (String s : storeInfoIdArr) {
                    list.add(Integer.valueOf(s));
                }
                this.tabStoreBusinessTimeMapper.deleteBystoreInfoIds(enterpriseId, list);
            }
            for (int i = 0; i < array.size(); i++) {
                JSONObject json = array.getJSONObject(i);
                String weekday = json.getString("weekday");
                String openTimeStr = json.getString("openTime");
                String closeTimeStr = json.getString("closeTime");
                Date openTime = simpleDateFormat.parse(openTimeStr);
                Date closeTime = simpleDateFormat.parse(closeTimeStr);
                if ("all".equals(storeInfoIds)) {
                    this.tabStoreBusinessTimeMapper.updateAllBuinessTime(weekday, openTime, closeTime, enterpriseId);
                } else {
                    this.tabStoreBusinessTimeMapper.updateBuinessTimeBystoreInfoIds(weekday, openTime, closeTime, list);
                }
            }

        } catch (Exception e) {
            logger.warn("异常：", e);
        }
        return 1;
    }

    @Override
    public int bulkUpdateStorePhoto(String storeInfoIds, Integer enterpriseId, String value) {
        try {
            JSONArray array = JSON.parseArray(value);
            List<Integer> list = new ArrayList<>();
            if (Constants.ALL.equals(storeInfoIds)) {
                this.tabStorePhotoMapper.deleteAllByEnterpriseId(enterpriseId);
            } else {
                String[] storeIdArr = storeInfoIds.split(",");
                for (String s : storeIdArr) {
                    list.add(Integer.valueOf(s));
                }
                this.tabStorePhotoMapper.deleteBystoreInfoIds(enterpriseId, list);
            }
            for (int i = 0; i < array.size(); i++) {
                JSONObject json = array.getJSONObject(i);
                String imageCode = json.getString("imageCode");
                String imageUrl = json.getString("imageUrl");
                if ("all".equals(storeInfoIds)) {
                    this.tabStorePhotoMapper.updateAllStorePhoto(imageCode, imageUrl, i, enterpriseId);
                } else {
                    this.tabStorePhotoMapper.updatePhotoBystoreInfoIds(imageCode, imageUrl, i, list);
                }
            }

        } catch (Exception e) {
            logger.warn("异常：", e);
        }
        return 0;
    }

    @Override
    public int bulkAddStorePhoto(String storeInfoIds, Integer enterpriseId, String value) {
        try {
            JSONArray array = JSON.parseArray(value);
            List<Integer> list = new ArrayList<>();
            for (int i = 0; i < array.size(); i++) {
                JSONObject json = array.getJSONObject(i);
                String imageCode = json.getString("imageCode");
                String imageUrl = json.getString("imageUrl");
                if ("all".equals(storeInfoIds)) {
                    this.tabStorePhotoMapper.addAllStorePhoto(imageCode, imageUrl, i, enterpriseId);
                } else {
                    String[] storeIdArr = storeInfoIds.split(",");
                    for (String s : storeIdArr) {
                        list.add(Integer.valueOf(s));
                    }
                    this.tabStorePhotoMapper.addPhotoBystoreInfoIds(imageCode, imageUrl, i, list);
                }
            }

        } catch (Exception e) {
            logger.warn("异常：", e);
        }
        return 1;
    }

    @Override
    public int bulkUpdateStoreBrands(String storeIds, Integer enterpriseId, String value) {
        try {
            List<Integer> list = new ArrayList<>();
            if (Constants.ALL.equals(storeIds)) {
                return this.tabStoreInfoMapper.updateAllStoreBrand(enterpriseId, value);
            } else {
                String[] storeIdArr = storeIds.split(",");
                for (String s : storeIdArr) {
                    list.add(Integer.valueOf(s));
                }
                return this.tabStoreInfoMapper.updateStoreBrandBystoreInfoIds(enterpriseId, value, list);
            }
        } catch (Exception e) {
            logger.warn("异常：", e);
        }
        return 0;
    }

    @Override
    public int bulkUpdateStoreGroup(String storeInfoIds, Integer enterpriseId, Integer value) {
        try {
            List<Integer> list = new ArrayList<>();
            if (Constants.ALL.equals(storeInfoIds)) {
                return this.tabStoreMapper.updateAllStoreGroup(enterpriseId, value);
            } else {
                String[] storeIdArr = storeInfoIds.split(",");
                for (String s : storeIdArr) {
                    list.add(Integer.valueOf(s));
                }
                return this.tabStoreMapper.updateStoreGroupBystoreInfoIds(enterpriseId, value, list);
            }
        } catch (Exception e) {
            logger.warn("异常：", e);
        }
        return 0;
    }

    @Override
    public StoreDTO getByStoreNameAndStoreCode(Integer enterpriseId, Integer regionId, String storeName, String storeCode) {
        return this.tabStoreInfoMapper.getByStoreNameAndStoreCode(enterpriseId, regionId, storeName, storeCode);
    }

    @Override
    public List<Integer> listAllStoreId(Integer enterpriseId) {
        return this.tabStoreInfoMapper.listAllstoreId(enterpriseId);
    }

    @Override
    public List<Integer> listAllStoreInfoId(Integer enterpriseId) {
        return this.tabStoreInfoMapper.listAllstoreInfoId(enterpriseId);
    }

    @Override
    public boolean validateStoreCodeIsExist(Integer enterpriseId, Integer regionId, String storeCode, Integer storeId) {
        StoreDTO store = new StoreDTO();
        store.setEnterpriseId(enterpriseId);
        store.setRegionId(regionId);
        store.setStoreCode(storeCode);
        store.setStoreId(storeId);
        TabStoreInfo result = this.tabStoreInfoMapper.getByStore(store);
        return result != null;
    }

    @Override
    public Integer validateStoreCodeIsExist(Integer enterpriseId, Integer regionId, String storeCode) {
        StoreDTO store = new StoreDTO();
        store.setEnterpriseId(enterpriseId);
        store.setRegionId(regionId);
        store.setStoreCode(storeCode);
        StoreDTO result = this.tabStoreInfoMapper.getDtoByStore(store);
        return result != null ? result.getStoreId() : null;
    }

    @Override
    public StoreDTO getStoreByRegionIdAndStoreCode(Integer enterpriseId, Integer regionId, String storeCode) {
        StoreDTO store = new StoreDTO();
        store.setEnterpriseId(enterpriseId);
        store.setRegionId(regionId);
        store.setStoreCode(storeCode);
        return this.tabStoreInfoMapper.getDtoByStore(store);
    }

    @Override
    public boolean validateStoreNameIsExist(Integer enterpriseId, Integer regionId, String storeName, Integer storeId) {
        if(StringUtils.isBlank(storeName)){
            return false;
        }
        StoreDTO store = new StoreDTO();
        store.setEnterpriseId(enterpriseId);
        store.setRegionId(regionId);
        store.setStoreName(storeName);
        store.setStoreId(storeId);
        TabStoreInfo result = this.tabStoreInfoMapper.getByStore(store);
        return result != null;
    }

    @Override
    public int authAddStore(StoreDTO storeDTO) {
        int result = 0;
        List<TabStore> list = this.tabStoreMapper.getStoreNoStatus(storeDTO.getEnterpriseId(), storeDTO.getStoreInfoId());
        TabStore store = new TabStore();
        if(CollectionUtils.isNotEmpty(list)){
            store = list.get(0);
        }
        store.setEnterpriseId(storeDTO.getEnterpriseId());
        store.setStoreInfoId(storeDTO.getStoreInfoId());
        store.setStoreGroupId(storeDTO.getStoreGroupId());
        store.setIsEditStoreGroup(storeDTO.getIsEditStoreGroup());
        store.setOwnType(storeDTO.getOwnType());
        store.setStatus(com.gic.enterprise.constants.Constants.NORMAL_STATUS);
        store.setUpdateTime(new Date());
        store.setFromEnterpriseId(storeDTO.getFromEnterpriseId());
        if(store.getStoreId() != null){
            result = this.tabStoreMapper.updateByPrimaryKeySelective(store);
        }else {
            store.setCreateTime(new Date());
            result = this.tabStoreMapper.insertSelective(store);
            storeDTO.setStoreId(store.getStoreId());
        }
        return result;
    }

    @Override
    public List<Integer> listStoreIdByFromEnterpriseId(Integer fromEnterpriseId) {
        return this.tabStoreMapper.listStoreIdByFromEnterpriseId(fromEnterpriseId);
    }

    @Override
    public int cancelAuthStore(List<Integer> storeInfoIdList, Integer toEnterpriseId) {
        return this.tabStoreMapper.cancelAuthStore(storeInfoIdList, toEnterpriseId);
    }

    @Override
    public int cancelAuthStoreAll(Integer fromEnterpriseId, Integer toEnterpriseId) {
        return this.tabStoreMapper.cancelAuthStoreAll(fromEnterpriseId, toEnterpriseId);
    }

    @Override
    public Integer getStoreOwnerByStoreInfoId(Integer enterpriseId, Integer storeInfoId) {
        return this.tabStoreInfoMapper.getStoreOwnerByStoreInfoId(enterpriseId, storeInfoId);
    }

    @Override
    public Integer getStoreIdByStoreInfoId(Integer enterpriseId, Integer storeInfoId) {
        return this.tabStoreInfoMapper.getStoreIdByStoreInfoId(enterpriseId, storeInfoId);
    }

    @Override
    public String listStoreInfoIdByStoreIds(String storeIds, Integer enterpriseId) {
        List<Integer> list = Stream.of(storeIds.split(GlobalInfo.FLAG_COMMA)).map(Integer::valueOf).collect(Collectors.toList());
        List<Integer> ids = tabStoreMapper.listStoreInfoIdByStoreIds(list, enterpriseId);
        return Optional.ofNullable(ids).orElse(Collections.emptyList()).stream().map(String::valueOf).collect(Collectors.joining(","));
    }

    @Override
    public List<Integer> listStoredByStoreInfoList(List<Integer> storeInfoIdList, Integer enterpriseId) {
        return tabStoreMapper.listStoredByStoreInfoList(storeInfoIdList, enterpriseId);
    }

    @Override
    public List<String> listAllCityId(Integer enterpriseId, Integer storeBrandId) {
        return this.tabStoreMapper.listAllCityId(enterpriseId, storeBrandId);
    }

    @Override
    public void updateStore(StoreDTO storeDTO) {
        TabStore tabStore = new TabStore();
        tabStore.setStoreId(storeDTO.getStoreId());
        tabStore.setScore(storeDTO.getScore());
        tabStore.setEvaluateCount(storeDTO.getEvaluateCount());
        this.tabStoreMapper.updateByPrimaryKeySelective(tabStore);
    }

    @Override
    public TabStore getByStoreCodeAndRegionId(Integer enterpriseId, Integer regionId, String storeCode) {
        StoreDTO storeDTO = new StoreDTO();
        storeDTO.setEnterpriseId(enterpriseId);
        storeDTO.setRegionId(regionId);
        storeDTO.setStoreCode(storeCode);
        TabStoreInfo store = this.tabStoreInfoMapper.getByStore(storeDTO);
        if (store == null) {
            return null;
        }
        List<TabStore> storeNoStatus = this.tabStoreMapper.getStoreNoStatus(enterpriseId, store.getStoreInfoId());
        if (CollectionUtils.isNotEmpty(storeNoStatus)) {
            TabStore tabStore = storeNoStatus.get(0);
            if (com.gic.enterprise.constants.Constants.NORMAL_STATUS.equals(tabStore.getStatus())) {
                return tabStore;
            }
        }

        return null;
    }

    @Override
    public Boolean checkExistStore(Integer enterpriseId) {
        Integer line = this.tabStoreMapper.checkExistStore(enterpriseId);
        return line != null;
    }

    @Override
    public int refreshStoreIndex(Integer enterpriseId) {
        return this.tabStoreMapper.refreshStoreIndex(enterpriseId);
    }

    @Override
    public int refreshStoreIndex(Integer enterpriseId, Integer storeGroupId) {
        return this.tabStoreMapper.refreshStoreIndexByStoreGroup(enterpriseId, storeGroupId);
    }
}