package com.gic.store.service.outer.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.*;
import com.gic.enterprise.constants.Constants;
import com.gic.enterprise.dto.wm.WmStoreSyncLogDTO;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.response.EnterpriseServiceResponse;
import com.gic.enterprise.service.EnterpriseApiService;
import com.gic.enterprise.service.WmStoreSyncLogApiService;
import com.gic.member.config.api.dto.UserOwnerDefaultDTO;
import com.gic.member.config.api.service.CardAscriptionConfigService;
import com.gic.mq.sdk.GicMQClient;
import com.gic.redis.data.util.RedisUtil;
import com.gic.spark.api.service.SparkJobApiService;
import com.gic.store.constant.*;
import com.gic.store.dto.*;
import com.gic.store.dto.clerk.OrderAddClerkDTO;
import com.gic.store.dto.clerk.PosAddClerkDTO;
import com.gic.store.dto.clerk.ProcessBatchClerkDTO;
import com.gic.store.entity.TabClerk;
import com.gic.store.entity.TabStoreRegion;
import com.gic.store.service.*;
import com.gic.weimob.api.dto.WeimobGuiderSynDTO;
import com.gic.weimob.api.service.WeimobStoreSiteService;
import com.github.pagehelper.PageHelper;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.concurrent.TimeUnit;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * @author zhiwj
 * @date 2019/7/16
 */
@Service("clerkApiService")
public class ClerkApiServiceImpl implements ClerkApiService {

    private static final Logger logger = LogManager.getLogger(ClerkApiServiceImpl.class);

    @Autowired
    private ClerkService clerkService;
    @Autowired
    private StoreGroupService storeGroupService;
    @Autowired
    private StoreService storeService;
    @Autowired
    private StoreApiService storeApiService;
    @Autowired
    private ClerkLogService clerkLogService;
    @Autowired
    private StoreLogService storeLogService;
    @Autowired
    private StoreRegionService storeRegionService;
    @Autowired
    private EnterpriseApiService enterpriseApiService;
    @Autowired
    private WeimobStoreSiteService weimobStoreSiteService;
    @Autowired
    private WmStoreSyncLogApiService wmStoreSyncLogApiService;
    @Autowired
    private ClerkPositionService clerkPositionService;
    @Autowired
    private SparkJobApiService sparkJobApiService;
    @Autowired
    private CardAscriptionConfigService cardAscriptionConfigService;

    @Override
    public ServiceResponse saveOrUpdate(ClerkDTO clerkDTO) {
        if (validStoreIsOther(clerkDTO.getEnterpriseId(), clerkDTO.getStoreInfoId())) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "权限不足");
        }
        // 校验参数
        if (StringUtils.isBlank(clerkDTO.getClerkCode())) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "导购代码不可为空");
        }
        if (StringUtils.isBlank(clerkDTO.getClerkName())) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "导购姓名不可为空");
        }
        if (com.gic.store.constant.Constants.NULL.equals(clerkDTO.getClerkCode().toLowerCase())) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "导购代码不可为null");
        }
        if (!clerkDTO.getClerkCode().matches(com.gic.store.constant.Constants.CLERK_CODE_REGEX)) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "导购代码仅支持数字和英文字符");
        }

        try {

            RedisUtil.lock("enterprise:clerk:position:" + clerkDTO.getStoreInfoId(), 3L, TimeUnit.SECONDS, 3L);
            if (clerkService.isRepeatByClerkCode(clerkDTO.getStoreInfoId(), clerkDTO.getClerkCode(), clerkDTO.getClerkId())) {
                return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "门店下导购代码重复");
            }
            // 店长逻辑
            // 如果门店下已经存在有导购是店长， 并且当前导购是店长 则做替换
            // 如果门店下没有导购是店长，将当前导购设置成店长
            // 这里并发会出错 加个锁
            TabClerk clerkLeader = clerkService.getClerkLeaderByStoreInfoId(clerkDTO.getEnterpriseId(), clerkDTO.getStoreInfoId());
            if (clerkLeader != null && com.gic.store.constant.Constants.CLERK_LEADER_POSITION_ID.equals(clerkDTO.getPositionId())) {
                clerkLeader.setPositionId(com.gic.store.constant.Constants.CLERK_POSITION_ID);
                clerkLeader.setPositionName("导购");
                clerkService.update(clerkLeader);
                clerkDTO.setPositionId(com.gic.store.constant.Constants.CLERK_LEADER_POSITION_ID);
            } else if (clerkLeader == null || clerkLeader.getClerkId().equals(clerkDTO.getClerkId())) {
                clerkDTO.setPositionId(com.gic.store.constant.Constants.CLERK_LEADER_POSITION_ID);
            }

            if (StringUtils.isNotBlank(clerkDTO.getPhoneNumber())) {
                String nationcode = clerkDTO.getNationcode();
                if (StringUtils.isBlank(nationcode)) {
                    nationcode = Constants.NATION_CODE;
                }
                //默认加上+
                if (!nationcode.contains(com.gic.store.constant.Constants.PLUS)) {
                    nationcode = com.gic.store.constant.Constants.PLUS + nationcode;
                }
                clerkDTO.setNationcode(nationcode);

                if (clerkService.isRepeatByPhoneNumber(clerkDTO.getStoreInfoId(), clerkDTO.getPhoneNumber(),
                        clerkDTO.getClerkId(), clerkDTO.getNationcode())) {
                    return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "门店下导购手机号重复");
                }
            }
            if (clerkDTO.getPositionId() == null) {
                clerkDTO.setPositionId(com.gic.store.constant.Constants.CLERK_POSITION_ID);
            }
            String positionName = this.clerkPositionService.getByClerkPositionId(clerkDTO.getPositionId()).getPositionName();
            clerkDTO.setPositionName(positionName);

            if (clerkDTO.getClerkId() == null) {
                //            Integer saveClerkLogBySaveClerk(Integer reason, Integer enterpriseId, Integer clerkId, String remark, Integer operatorId, String operatorName);
                Integer id = clerkService.save(clerkDTO);
                clerkDTO.setClerkId(id);
                clerkLogService.saveClerkLogBySaveClerk(clerkDTO.getEnterpriseId(), id, clerkDTO.getReason(),
                        clerkDTO.getRemark(), clerkDTO.getOperatorId(), clerkDTO.getOperatorName());
                storeLogByAddClerk(clerkDTO);

                synClerkInfoToWeimobMq(clerkDTO);
            } else {
                TabClerk oldClerk = this.clerkService.getById(clerkDTO.getClerkId());
                clerkService.update(clerkDTO);
                clerkLogService.saveClerkLogByUpdateClerk(oldClerk, clerkDTO, clerkDTO.getEnterpriseId(),
                        clerkDTO.getClerkId(), clerkDTO.getReason(), clerkDTO.getRemark(), clerkDTO.getOperatorId(),
                        clerkDTO.getOperatorName());

                synClerkInfoToWeimobMq(clerkDTO);
            }
            return ServiceResponse.success(clerkDTO.getClerkId());
        }finally {
            RedisUtil.unlock("enterprise:clerk:position:" + clerkDTO.getStoreInfoId());
        }
    }

    @Override
    public ServiceResponse<Void> verifyParam(ClerkDTO clerkDTO) {
        if (validStoreIsOther(clerkDTO.getEnterpriseId(), clerkDTO.getStoreInfoId())) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "权限不足");
        }
        // 校验参数
        if (StringUtils.isBlank(clerkDTO.getClerkCode())) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "导购代码不可为空");
        }
        if (StringUtils.isBlank(clerkDTO.getClerkName())) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "导购姓名不可为空");
        }
        if (com.gic.store.constant.Constants.NULL.equals(clerkDTO.getClerkCode().toLowerCase())) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "导购代码不可为null");
        }
        if (!clerkDTO.getClerkCode().matches(com.gic.store.constant.Constants.CLERK_CODE_REGEX)) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "导购代码仅支持数字和英文字符");
        }
        if (clerkService.isRepeatByClerkCode(clerkDTO.getStoreInfoId(), clerkDTO.getClerkCode(), clerkDTO.getClerkId())) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "门店下导购代码重复");
        }
        if (clerkService.isRepeatByPhoneNumber(clerkDTO.getStoreInfoId(), clerkDTO.getPhoneNumber(), clerkDTO.getClerkId(), clerkDTO.getNationcode())) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "门店下导购手机号重复");
        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<Void> saveOrUpdateFromHaoban(ClerkDTO clerkDTO) {
        logger.info("好办保存导购：{}", JSON.toJSONString(clerkDTO));
        return this.saveOrUpdate(clerkDTO);
    }

    @Override
    public ServiceResponse<Integer> saveClerkForOrder(String clerkName, String clerkCode, Integer storeInfoId,
            Integer enterpriseId, String orderNum) {
            ClerkDTO clerkDTO = new ClerkDTO();
            clerkDTO.setClerkName(clerkName);
            clerkDTO.setClerkCode(clerkCode);
            clerkDTO.setEnterpriseId(enterpriseId);
            clerkDTO.setStoreInfoId(storeInfoId);
            clerkDTO.setReason(ClerkLogReasonEnum.ORDER.getCode());
            clerkDTO.setRemark("订单号:" + orderNum);
            ServiceResponse serviceResponse = this.saveOrUpdate(clerkDTO);
            return serviceResponse;
    }

    @Override
    public ServiceResponse<Integer> saveClerkForPosMember(String clerkName, String clerkCode, Integer storeInfoId, Integer enterpriseId, String cardNo) {
        Integer storeId = storeService.getStoreIdByStoreInfoId(enterpriseId, storeInfoId);
        if (storeId != null) {
            ClerkDTO clerkDTO = new ClerkDTO();
            clerkDTO.setClerkName(clerkName);
            clerkDTO.setClerkCode(clerkCode);
            clerkDTO.setEnterpriseId(enterpriseId);
            clerkDTO.setStoreInfoId(storeInfoId);
            clerkDTO.setReason(ClerkLogReasonEnum.MEMBER.getCode());
            clerkDTO.setRemark("卡号:" + cardNo);
            ServiceResponse serviceResponse = this.saveOrUpdate(clerkDTO);
            return serviceResponse;
        } else {
            logger.warn("门店不存在 enterpriseId:{}, storeId:{}", enterpriseId, storeInfoId);
            return EnterpriseServiceResponse.failure(ErrorCode.NOTEXISTS.getCode(), "门店不存在");
        }
    }

    @Override
    public ServiceResponse<Integer> saveClerkForPosMember(PosAddClerkDTO posAddClerkDTO) {
        Integer storeId = storeService.getStoreIdByStoreInfoId(posAddClerkDTO.getEnterpriseId(), posAddClerkDTO.getStoreInfoId());
        if (storeId != null) {
            ClerkDTO clerkDTO = new ClerkDTO();
            clerkDTO.setClerkName(posAddClerkDTO.getClerkName());
            clerkDTO.setClerkCode(posAddClerkDTO.getClerkCode());
            clerkDTO.setEnterpriseId(posAddClerkDTO.getEnterpriseId());
            clerkDTO.setStoreInfoId(posAddClerkDTO.getStoreInfoId());
            clerkDTO.setReason(ClerkLogReasonEnum.MEMBER.getCode());
            clerkDTO.setRemark("卡号:" + posAddClerkDTO.getCardNo());

            clerkDTO.setStatus((posAddClerkDTO.getOpenCardTime().getTime() + 15552000000L) > System.currentTimeMillis() ? 1 : 0);

            ServiceResponse serviceResponse = this.saveOrUpdate(clerkDTO);
            return serviceResponse;
        } else {
            logger.warn("门店不存在 enterpriseId:{}, storeInfoId:{}", posAddClerkDTO.getEnterpriseId(), posAddClerkDTO.getStoreInfoId());
            return EnterpriseServiceResponse.failure(ErrorCode.NOTEXISTS.getCode(), "门店不存在");
        }
    }

    @Override
    public ServiceResponse<Integer> saveClerkByStoreInfoIdForOrder(String clerkName, String clerkCode, Integer storeInfoId, Integer enterpriseId, String orderNum) {
            ClerkDTO clerkDTO = new ClerkDTO();
            clerkDTO.setClerkName(clerkName);
            clerkDTO.setClerkCode(clerkCode);
            clerkDTO.setEnterpriseId(enterpriseId);
            clerkDTO.setStoreInfoId(storeInfoId);
            clerkDTO.setReason(ClerkLogReasonEnum.ORDER.getCode());
            clerkDTO.setRemark("订单号:" + orderNum);

            ServiceResponse serviceResponse = this.saveOrUpdate(clerkDTO);
            return serviceResponse;
    }

    @Override
    public ServiceResponse<Integer> saveClerkByStoreInfoIdForOrder(OrderAddClerkDTO orderAddClerkDTO) {
        ClerkDTO clerkDTO = new ClerkDTO();
        clerkDTO.setClerkName(orderAddClerkDTO.getClerkName());
        clerkDTO.setClerkCode(orderAddClerkDTO.getClerkCode());
        clerkDTO.setEnterpriseId(orderAddClerkDTO.getEnterpriseId());
        clerkDTO.setStoreInfoId(orderAddClerkDTO.getStoreInfoId());
        clerkDTO.setReason(ClerkLogReasonEnum.ORDER.getCode());
        clerkDTO.setRemark("订单号:" + orderAddClerkDTO.getOrderNum());
        clerkDTO.setStatus((orderAddClerkDTO.getOrderTime().getTime() + 15552000000L) > System.currentTimeMillis() ? 1 : 0);

        ServiceResponse serviceResponse = this.saveOrUpdate(clerkDTO);
        return serviceResponse;
    }

    @Override
    public ServiceResponse<ClerkDTO> getClerkByCode(Integer enterpriseId, String clerkCode, Integer storeId) {
        ServiceResponse<StoreDTO> storeResponse = storeApiService.getStoreById(enterpriseId, storeId);
        if (storeResponse.getResult() != null) {
            StoreDTO store = storeResponse.getResult();
            return getClerkByCodeAndStoreInfoId(enterpriseId, clerkCode, storeId);
        } else {
            logger.warn("门店不存在 enterpriseId:{}, storeId:{}", enterpriseId, storeId);
            return EnterpriseServiceResponse.failure(ErrorCode.NOTEXISTS.getCode(), "门店不存在");
        }
    }

    @Override
    public ServiceResponse<ClerkDTO> getClerkByCodeAndStoreInfoId(Integer enterpriseId, String clerkCode, Integer storeInfoId) {
        TabClerk clerk = this.clerkService.getClerkByCode(enterpriseId, clerkCode, storeInfoId);
        if (clerk != null) {
            return EnterpriseServiceResponse.success(EntityUtil.changeEntityByJSON(ClerkDTO.class, clerk));
        } else {
            return EnterpriseServiceResponse.failure(ErrorCode.NOTEXISTS);
        }
    }

    private void storeLogByAddClerk(ClerkDTO clerkDTO) {
        try {
            StoreLogDTO storeLogDTO = new StoreLogDTO();
            storeLogDTO.setEnterpriseId(clerkDTO.getEnterpriseId());
            Integer storeId = this.storeService.getStoreIdByStoreInfoId(clerkDTO.getEnterpriseId(),
                    clerkDTO.getStoreInfoId());
            storeLogDTO.setStoreId(storeId);
            storeLogDTO.setContent("门店关联导购【导购编码" + clerkDTO.getClerkCode() + "】");
            storeLogDTO.setReason(clerkDTO.getReason());
            storeLogDTO.setLogType(StoreLogTypeEnum.ADD_CLERK.getCode());
            storeLogDTO.setRemark(clerkDTO.getRemark());
            storeLogDTO.setOperatorId(clerkDTO.getOperatorId());
            storeLogDTO.setOperatorName(clerkDTO.getOperatorName());

            storeLogService.saveStoreLog(storeLogDTO);
        } catch (Exception e) {
            logger.warn("保存导购日志出错", e);
        }
    }

    private boolean validStoreIsOther(Integer enterpriseId, Integer storeInfoId) {
        Integer owner = storeService.getStoreOwnerByStoreInfoId(enterpriseId, storeInfoId);
        if (owner == null) {
            return false;
        }
        return owner == StoreOwnTypeEnum.OTHER.getCode();
    }

    @Override
    @SuppressWarnings("unchecked")
    public ServiceResponse<Page<ClerkStoreListDTO>> listClerk(Integer enterpriseId, ClerkSearchDTO clerkSearchDTO,
            Integer pageNum, Integer pageSize) {

        boolean hasStoreIds = StringUtils.isNotBlank(clerkSearchDTO.getStoreIds());
        //如果有门店数据条件，则不判断门店分组数据，因为分店分组数据也是为了获取门店
        if (!hasStoreIds) {
            if (clerkSearchDTO.getStoreGroupId() == null) {
                return ServiceResponse.failure(ErrorCode.MISS_PARAMETER.getCode(), ErrorCode.MISS_PARAMETER.getMsg());
            }
        }

        if (StringUtils.isNotBlank(clerkSearchDTO.getSearch())) {
            List<Integer> storeInfoIdsBySearch = clerkService.getStoreInfoIdsBySearch(enterpriseId, clerkSearchDTO.getSearch());
            if (CollectionUtils.isNotEmpty(storeInfoIdsBySearch)) {
                String storeInfoIds = storeInfoIdsBySearch.stream().map(Object::toString).collect(Collectors.joining(" "));
                clerkSearchDTO.setStoreInfoIds(storeInfoIds);
            } else {
                return ServiceResponse.success();
            }
        }

        ServiceResponse<Page<StoreDTO>> serviceResponse = listStoreIds(clerkSearchDTO, pageNum, pageSize);
        if (!serviceResponse.isSuccess()) {
            return ServiceResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
        Page<StoreDTO> page = serviceResponse.getResult();
        if (page == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "ES门店数据为空");
        }
        List<StoreDTO> storeList = page.getResult();
        List<Integer> storeInfoIds = new ArrayList<>(storeList.size());
        List<ClerkStoreListDTO> storeClerkDTOList = new ArrayList<>(storeList.size());
        for (StoreDTO store : storeList) {
            ClerkStoreListDTO clerkStoreListDTO = new ClerkStoreListDTO();
            clerkStoreListDTO.setStoreId(store.getStoreId());
            clerkStoreListDTO.setStoreInfoId(store.getStoreInfoId());
            clerkStoreListDTO.setStoreName(store.getStoreName());
            clerkStoreListDTO.setStoreCode(store.getStoreCode());
            clerkStoreListDTO.setOwnType(store.getOwnType());
            storeClerkDTOList.add(clerkStoreListDTO);
            storeInfoIds.add(store.getStoreInfoId());
        }
        List<TabClerk> clerkList = clerkService.listClerkByStoreInfoId(enterpriseId, storeInfoIds,
                clerkSearchDTO.getSearch(), clerkSearchDTO.getClerkType());
        Map<Integer, List<TabClerk>> storeIdMap = CollectionUtil.group(clerkList, "storeInfoId");
        for (ClerkStoreListDTO clerkStoreListDTO : storeClerkDTOList) {
            List<TabClerk> tabClerks = storeIdMap.get(clerkStoreListDTO.getStoreInfoId());
            if (CollectionUtils.isNotEmpty(tabClerks)) {
                clerkStoreListDTO.setClerkList(EntityUtil.changeEntityListByOrika(ClerkDTO.class, tabClerks));
            } else {
                clerkStoreListDTO.setClerkList(Collections.emptyList());
            }
        }
        Page resultPage = new Page();
        resultPage.setPageSize(page.getPageSize());
        resultPage.setCurrentPage(page.getCurrentPage());
        resultPage.setTotalCount(page.getTotalCount());
        resultPage.setTotalPage(page.getPages());
        resultPage.setResult(storeClerkDTOList);
        return ServiceResponse.success(resultPage);
    }

    @Override
    public ServiceResponse<Integer> getTotalClerk(Integer enterpriseId, ClerkSearchDTO clerkSearchDTO) {
        boolean hasStoreIds = StringUtils.isNotBlank(clerkSearchDTO.getStoreIds());
        //如果有门店数据条件，则不判断门店分组数据，因为分店分组数据也是为了获取门店
        if (!hasStoreIds) {
            if (clerkSearchDTO.getStoreGroupId() == null) {
                return ServiceResponse.failure(ErrorCode.MISS_PARAMETER.getCode(), ErrorCode.MISS_PARAMETER.getMsg());
            }
        }

        if (StringUtils.isNotBlank(clerkSearchDTO.getSearch())) {
            List<Integer> storeInfoIdsBySearch = clerkService.getStoreInfoIdsBySearch(enterpriseId, clerkSearchDTO.getSearch());
            if (CollectionUtils.isNotEmpty(storeInfoIdsBySearch)) {
                String storeInfoIds = storeInfoIdsBySearch.stream().map(Object::toString).collect(Collectors.joining(" "));
                clerkSearchDTO.setStoreInfoIds(storeInfoIds);
            } else {
                return ServiceResponse.success();
            }
        }

        ServiceResponse<Page<StoreDTO>> serviceResponse = listStoreIds(clerkSearchDTO, 1, Integer.MAX_VALUE);
        if (!serviceResponse.isSuccess()) {
            return ServiceResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
        Page<StoreDTO> page = serviceResponse.getResult();
        if (page == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "ES门店数据为空");
        }
        List<Integer> storeInfoIds = page.getResult().stream().map(StoreDTO::getStoreInfoId)
                .collect(Collectors.toList());
        if (CollectionUtils.isNotEmpty(storeInfoIds)) {
            Integer totalClerk = clerkService.getTotalClerk(enterpriseId, storeInfoIds, clerkSearchDTO);
            return ServiceResponse.success(totalClerk);
        } else {
            return ServiceResponse.success(0);
        }

    }

    private String getStoreIdByStoreInfoIds(List<Integer> storeInfoIdsBySearch, String search) {
        StoreSearchDbDTO storeSearchDbDTO = new StoreSearchDbDTO();
        storeSearchDbDTO.setStoreInfoIdList(storeInfoIdsBySearch);
        storeSearchDbDTO.setSearch(search);
        List<StoreDTO> dtos = storeService.listStore(storeSearchDbDTO, 1, Integer.MAX_VALUE);
        return Optional.ofNullable(dtos).orElse(Collections.emptyList()).stream().map(e -> e.getStoreId().toString()).collect(Collectors.joining(" "));
    }


    @SuppressWarnings("unchecked")
    private ServiceResponse<Page<StoreDTO>> listStoreIds(ClerkSearchDTO clerkSearchDTO, Integer pageNum,
            Integer pageSize) {
        StoreSearchDTO storeSearchDTO = new StoreSearchDTO();
        storeSearchDTO.setEnterpriseId(clerkSearchDTO.getEnterpriseId());
        storeSearchDTO.setStoreGroupId(clerkSearchDTO.getStoreGroupId());
        storeSearchDTO.setSearchJson(clerkSearchDTO.getSearchJson());
        storeSearchDTO.setStoreIds(clerkSearchDTO.getStoreIds());
        storeSearchDTO.setSearch(clerkSearchDTO.getStoreSearch());
        storeSearchDTO.setStoreInfoIds(clerkSearchDTO.getStoreInfoIds());

        return storeApiService.listStore(storeSearchDTO, pageNum, pageSize,
                "storeId,storeName,storeCode,storeInfoId,ownType");
    }

    @Override
    public ServiceResponse updateClerkStatus(Integer enterpriseId, String clerkIds, Integer status) {
        List<Integer> clerkIdList;
        if (StringUtils.isNotBlank(clerkIds)) {
            if (StringUtils.equals(com.gic.store.constant.Constants.ALL, clerkIds)) {
                clerkIdList = clerkService.listAllClerkId(enterpriseId);
            } else {
                String[] split = clerkIds.split(GlobalInfo.FLAG_COMMA);
                clerkIdList = Stream.of(split).map(Integer::parseInt).collect(Collectors.toList());
            }
            if(StoreStatusEnum.INONLINE.getCode() == status){
                List<UserOwnerDefaultDTO> result = this.cardAscriptionConfigService.getDefaultUserOwner(enterpriseId).getResult();
                if(CollectionUtils.isNotEmpty(result)){
                    clerkIdList = clerkIdList.stream().filter(clerkId -> {
                        for(UserOwnerDefaultDTO dto : result){
                            if(clerkId.intValue() == dto.getClerkId().intValue()){
                                return false;
                            }
                        }
                        return true;
                    }).collect(Collectors.toList());
                }
            }
            if(CollectionUtils.isNotEmpty(clerkIdList)){
                Integer i = clerkService.updateClerkStatus(enterpriseId, clerkIdList, status);
                for (Integer clerkId : clerkIdList) {
                    sparkJobApiService.updateClerkStatus(enterpriseId, clerkId.longValue(), 1 == status ? 0 : 1);
                }
            }
        }

        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<List<ClerkDTO>> listClerkByIds(Integer enterpriseId, String clerkIds) {
        List<TabClerk> clerkList = clerkService.listClerkByIds(enterpriseId, clerkIds);
        List<ClerkDTO> clerkDTOList = EntityUtil.changeEntityListByJSON(ClerkDTO.class, clerkList);
        return EnterpriseServiceResponse.success(clerkDTOList);
    }

    @Override
    public ServiceResponse<List<ClerkDTO>> listClerkByStoreId(Integer enterpriseId, Integer storeId, String search) {
        ServiceResponse<StoreDTO> response = storeApiService.getStoreById(enterpriseId, storeId);
        if (response.isSuccess() && response.getResult() != null) {
            List<Integer> storeInfoIds = new ArrayList<>();
            storeInfoIds.add(response.getResult().getStoreInfoId());
            List<TabClerk> clerkList = this.clerkService.listClerkByStoreInfoId(enterpriseId, storeInfoIds, search);
            return ServiceResponse.success(EntityUtil.changeEntityListByJSON(ClerkDTO.class, clerkList));
        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<List<ClerkDTO>> listClerkByStoreInfoId(Integer enterpriseId, Integer storeInfoId, String search) {
        List<Integer> storeInfoIds = new ArrayList<>();
        storeInfoIds.add(storeInfoId);
        List<TabClerk> clerkList = this.clerkService.listClerkByStoreInfoId(enterpriseId, storeInfoIds, search);
        return ServiceResponse.success(EntityUtil.changeEntityListByJSON(ClerkDTO.class, clerkList));
    }

    @Override
    public ServiceResponse<Page<ClerkDTO>> pageClerkByStoreInfoId(Integer enterpriseId, Integer storeInfoId, String search, Integer pageNum, Integer pageSize) {
        List<Integer> storeInfoIds = new ArrayList<>();
        storeInfoIds.add(storeInfoId);
        PageHelper.startPage(pageNum, pageSize);
        List<TabClerk> clerkList = this.clerkService.listClerkByStoreInfoId(enterpriseId, storeInfoIds, search);
        return ServiceResponse.success(PageHelperUtils.changePageHelperToCurrentPage(clerkList, ClerkDTO.class));
    }

    @Override
    public ServiceResponse<ClerkDTO> getHeadClerk(Integer enterpriseId, Integer storeId) {
        ServiceResponse<StoreDTO> response = storeApiService.getStoreById(enterpriseId, storeId);
        if (response.isSuccess() && response.getResult() != null) {
            return this.getHeadClerkByStoreInfoId(enterpriseId, response.getResult().getStoreInfoId());
        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<ClerkDTO> getHeadClerkByStoreInfoId(Integer enterpriseId, Integer storeInfoId) {
        TabClerk clerkLeader = clerkService.getClerkLeaderByStoreInfoId(enterpriseId, storeInfoId);
        if (clerkLeader != null) {
            return ServiceResponse.success(EntityUtil.changeEntityNew(ClerkDTO.class, clerkLeader));
        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<ClerkDTO> getClerkById(Integer enterpriseId, Integer clerkId) {
        TabClerk tabClerk = this.clerkService.getById(clerkId);
        ClerkDTO clerkDTO = EntityUtil.changeEntityByJSON(ClerkDTO.class, tabClerk);
        if (clerkDTO != null) {
            StoreDTO storeDTO = this.storeApiService.getStoreByStoreInfoId(enterpriseId, clerkDTO.getStoreInfoId()).getResult();
            if (storeDTO != null) {
                clerkDTO.setStoreName(storeDTO.getStoreName());
            }
        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<List<ClerkDTO>> listClerk(Integer enterpriseId, String search) {
        List<TabClerk> clerkList = this.clerkService.listClerkByStoreInfoId(enterpriseId, search);
        return ServiceResponse.success(EntityUtil.changeEntityListByJSON(ClerkDTO.class, clerkList));
    }

    @Override
    public ServiceResponse<String> importClerkForOperation(ProcessBatchClerkDTO clerkInfo) {
        if (clerkInfo == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "对象为空");
        }
        logger.info("批量处理导购的参数：{}", JSONObject.toJSONString(clerkInfo));
        //param valid
        Integer regionId = clerkInfo.getRegionId();
        Integer enterpriseId = clerkInfo.getEnterpriseId();
        //商户ID校验
        ServiceResponse enterpriseResult = enterpriseApiService.getEnterpriseById(enterpriseId);
        if (!enterpriseResult.isSuccess()) {
            return responseErrorElement(ImportClerkBatchResultEnum.E1);
        }
        if (regionId == null) {
            return responseErrorElement(ImportClerkBatchResultEnum.A1);
        }
        TabStoreRegion tabStoreRegion = storeRegionService.getById(enterpriseId, regionId);
        if (tabStoreRegion == null) {
            return responseErrorElement(ImportClerkBatchResultEnum.A2);
        }
        String storeCode = clerkInfo.getStoreCode();
        if (StringUtils.isBlank(storeCode)) {
            return responseErrorElement(ImportClerkBatchResultEnum.A3);
        }
        StoreDTO storeDTO = storeService.getStoreByRegionIdAndStoreCode(enterpriseId, tabStoreRegion.getRegionId(),
                clerkInfo.getStoreCode());
        if (storeDTO == null) {
            return responseErrorElement(ImportClerkBatchResultEnum.A4);
        }
        Integer storeInfoId = storeDTO.getStoreInfoId();
        String clerkCode = clerkInfo.getClerkCode();
        if (StringUtils.isBlank(clerkCode)) {
            return responseErrorElement(ImportClerkBatchResultEnum.C1);
        }
        if (StringUtils.isBlank(clerkInfo.getClerkName())) {
            return responseErrorElement(ImportClerkBatchResultEnum.C3);
        }
        String nationcode = clerkInfo.getNationcode();
        if (StringUtils.isBlank(nationcode)) {
            nationcode = Constants.NATION_CODE;
        }
        Integer gender = clerkInfo.getClerkGender();
        if (gender != null && gender != GenderEnum.MALE.getCode() && gender != GenderEnum.FEMALE.getCode()) {
            return responseErrorElement(ImportClerkBatchResultEnum.D2);
        }
        String phone = clerkInfo.getPhoneNumber();
        if (StringUtils.isBlank(phone)) {
            return responseErrorElement(ImportClerkBatchResultEnum.D4);
        }
        if (clerkInfo.getClerkType() == null) {
            return responseErrorElement(ImportClerkBatchResultEnum.D5);
        }
        if (clerkService.isRepeatByPhoneNumber(storeInfoId, phone, null, nationcode)) {
            return responseErrorElement(ImportClerkBatchResultEnum.D3);
        }
        ClerkDTO clerkDTO = EntityUtil.changeEntityNew(ClerkDTO.class, clerkInfo);
        if (clerkInfo.getClerkType() == 1) {
            clerkDTO.setPositionId(com.gic.store.constant.Constants.CLERK_LEADER_POSITION_ID);
        } else if (clerkInfo.getClerkType() == 0) {
            clerkDTO.setPositionId(com.gic.store.constant.Constants.CLERK_POSITION_ID);
        }

        TabClerk clerk = this.clerkService.getClerkByCode(enterpriseId, clerkCode, storeInfoId);
        boolean isAdd = true;
        //如果代购code存在，则进行更新操作
        if (clerk != null) {
            clerkDTO.setClerkId(clerk.getClerkId());
            isAdd = false;
        }
        clerkDTO.setStoreInfoId(storeInfoId);
        clerkDTO.setStoreName(storeDTO.getStoreName());

        ServiceResponse serviceResponse = saveOrUpdate(clerkDTO);
        if (!serviceResponse.isSuccess()) {
            return serviceResponse;
        }
        Integer id = (Integer) serviceResponse.getResult();
        id = saveClerkLog(enterpriseId, clerkDTO, clerk, isAdd, id);
        //性别为空，但是标记导入
        if (gender == null) {
            return responseErrorElement(ImportClerkBatchResultEnum.D1);
        }
        return ServiceResponse.success(id.toString());
    }

    private Integer saveClerkLog(Integer enterpriseId, ClerkDTO clerkDTO, TabClerk clerk, boolean isAdd, Integer id) {
        if (isAdd) {
            clerkLogService.saveClerkLogBySaveClerk(enterpriseId, id, clerkDTO.getReason(),
                    clerkDTO.getRemark(), clerkDTO.getOperatorId(), clerkDTO.getOperatorName());
            storeLogByAddClerk(clerkDTO);
        } else {
            id = clerk.getClerkId();
            clerkDTO.setClerkId(id);
            clerkLogService.saveClerkLogByUpdateClerk(clerk, clerkDTO, clerkDTO.getEnterpriseId(),
                    clerkDTO.getClerkId(), clerkDTO.getReason(), clerkDTO.getRemark(), clerkDTO.getOperatorId(),
                    clerkDTO.getOperatorName());
        }
        return id;
    }

    @Override
    public ServiceResponse<Integer> addClerkToOtherStore(Integer clerkId, Integer storeInfoId, Integer enterpriseId) {
        logger.info("clerkId:{}, storeInfoId:{}, enterpriseId:{}", clerkId, storeInfoId, enterpriseId);
        TabClerk clerk = this.clerkService.getById(clerkId);
        if (clerk == null) {
            return EnterpriseServiceResponse.failure(ErrorCode.NOTEXISTS.getCode(), "导购不存在");
        }
        StoreDTO store = this.storeApiService.getStoreByStoreInfoId(enterpriseId, storeInfoId).getResult();
        if (store == null) {
            return EnterpriseServiceResponse.failure(ErrorCode.NOTEXISTS.getCode(), "门店不存在");
        }
        if (clerk.getStoreInfoId().equals(store.getStoreInfoId())) {
            logger.info("导购[clerkId:{}]已存在门店[storeId:{}, storeInfoId:{}]下", clerkId, store.getStoreId(), store.getStoreInfoId());
            return EnterpriseServiceResponse.success(clerkId);
        }
        ClerkDTO clerkDTO = EntityUtil.changeEntityByJSON(ClerkDTO.class, clerk);
        clerkDTO.setClerkId(null);
        clerkDTO.setStoreInfoId(store.getStoreInfoId());
        ServiceResponse<Integer> clerkResp = this.saveOrUpdate(clerkDTO);
        if (clerkResp.isSuccess()) {
            logger.info("导购[clerkId:{}]不存在门店[storeId:{}, storeInfoId:{}]下, 新增clerkId：{}", clerkId, store.getStoreId(), store.getStoreInfoId(), clerkResp.getResult());
            return EnterpriseServiceResponse.success(clerkResp.getResult());
        } else {
            logger.info("保存导购失败：{}", clerkResp.getMessage());
            return EnterpriseServiceResponse.failure(clerkResp.getCode(), clerkResp.getMessage());
        }
    }

    @Override
    public ServiceResponse<Boolean> ensureClerkInStore(Integer clerkId, Integer storeInfoId, Integer enterpriseId) {
        logger.info("clerkId:{}, storeInfoId:{}, enterpriseId:{}", clerkId, storeInfoId, enterpriseId);
        TabClerk clerk = this.clerkService.getById(clerkId);
        if (clerk == null) {
            return EnterpriseServiceResponse.failure(ErrorCode.NOTEXISTS.getCode(), "导购不存在", Boolean.FALSE);
        }
        StoreDTO store = this.storeApiService.getStoreByStoreInfoId(enterpriseId, storeInfoId).getResult();
        if (store == null) {
            return EnterpriseServiceResponse.failure(ErrorCode.NOTEXISTS.getCode(), "门店不存在", Boolean.FALSE);
        }
        if (clerk.getStoreInfoId().equals(storeInfoId)) {
            logger.info("导购[clerkId:{}]已存在门店[storeId:{}, storeInfoId:{}]下", clerkId, store.getStoreId(), store.getStoreInfoId());
            return EnterpriseServiceResponse.success(Boolean.TRUE);
        } else {
            logger.info("导购[clerkId:{}]不存在门店[storeId:{}, storeInfoId:{}]下", clerkId, store.getStoreId(), store.getStoreInfoId());
            return EnterpriseServiceResponse.failure(ErrorCode.NOTEXISTS.getCode(), "导购不存在该门店下", Boolean.FALSE);
        }
    }

    @Override
    public ServiceResponse<List<ClerkDTO>> listClerkByStoreBrand(Integer enterpriseId, Integer storeBrandId, String clerkName) {
        StoreSearchDbDTO storeSearchDbDTO = new StoreSearchDbDTO();
        storeSearchDbDTO.setEnterpriseId(enterpriseId);
        storeSearchDbDTO.setStoreBrandId(storeBrandId);
        List<StoreDTO> list = this.storeService.listStore(storeSearchDbDTO, 1, 10000);
        if (CollectionUtils.isEmpty(list)) {
            return EnterpriseServiceResponse.failure(ErrorCode.NOTEXISTS);
        }
        // list 如果太大， 让 mybatis 解析 会打满内存
        String storeInfoIds = list.stream().map(e -> e.getStoreInfoId().toString()).collect(Collectors.joining(","));
        storeInfoIds = "(" + storeInfoIds + ")";
        List<TabClerk> clerkList = this.clerkService.listClerkByStoreInfoId(enterpriseId, storeInfoIds, clerkName);
        List<ClerkDTO> dtoList = EntityUtil.changeEntityListByJSON(ClerkDTO.class, clerkList);
        return EnterpriseServiceResponse.success(dtoList);
    }

    @Override
    public ServiceResponse updateClerkLeader(Integer clerkId) {
        TabClerk clerk = this.clerkService.getById(clerkId);
        clerk.setPositionId(com.gic.store.constant.Constants.CLERK_LEADER_POSITION_ID);
        TabClerk oldClerk = this.clerkService.getClerkLeaderByStoreInfoId(clerk.getEnterpriseId(), clerk.getStoreInfoId());
        oldClerk.setPositionId(com.gic.store.constant.Constants.CLERK_POSITION_ID);

        this.clerkService.update(oldClerk);
        this.clerkService.update(clerk);

        return EnterpriseServiceResponse.success();
    }

    @Override
    public ServiceResponse<Void> syncClerkToWeimob(Integer wmMallStoreId, List<Integer> storeIdList, Integer enterpriseId) {
        ClerkSearchDTO searchDTO = new ClerkSearchDTO();
        searchDTO.setEnterpriseId(enterpriseId);
        StringBuilder sb = new StringBuilder();
        storeIdList.forEach(e -> sb.append(e).append(" "));
        searchDTO.setStoreIds(sb.toString());
        ServiceResponse<Page<ClerkStoreListDTO>> pageResult = listClerk(enterpriseId, searchDTO, 1, storeIdList.size());
        logger.info("同步门店-同步导购-查询导购数据结果:{}", JSONObject.toJSONString(pageResult));
        if (pageResult.isSuccess()) {
            Page<ClerkStoreListDTO> page = pageResult.getResult();
            if (page != null) {
                List<ClerkStoreListDTO> list = page.getResult();
                if (CollectionUtils.isNotEmpty(list)) {
                    list.forEach(e -> {
                        List<ClerkDTO> clerkList = e.getClerkList();
                        if (CollectionUtils.isNotEmpty(clerkList)) {
                            clerkList.forEach(clerk -> {
                                WeimobGuiderSynDTO weimobGuiderSynDTO = new WeimobGuiderSynDTO();
                                weimobGuiderSynDTO.setStoreNumber(e.getStoreCode());
                                weimobGuiderSynDTO.setClerkId(clerk.getClerkId());
                                weimobGuiderSynDTO.setGuiderName(clerk.getClerkName());
                                weimobGuiderSynDTO.setGuiderPhone(clerk.getPhoneNumber());
                                weimobGuiderSynDTO.setJobNumber(clerk.getClerkCode());
                                weimobGuiderSynDTO.setStoreInfoId(e.getStoreInfoId());
                                asynClerkInfoToWeimobMq(wmMallStoreId, enterpriseId, weimobGuiderSynDTO);
                            });
                        }
                    });
                }
            }
        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<Void> syncClerkToWeimobTask(String param) {
        JSONObject jsonObject = JSONObject.parseObject(param);
        String enterpriseId = jsonObject.getString("enterpriseId");
        String wmMallStoreId = jsonObject.getString("wmMallStoreId");
        String wmGuiderDtoStr = (String) jsonObject.get("wmGuiderDTO");
        WeimobGuiderSynDTO wmGuiderDTO = JSONObject.parseObject(wmGuiderDtoStr, WeimobGuiderSynDTO.class);
        logger.info("异步导购微盟放入参数:{}", JSONObject.toJSONString(wmGuiderDTO));
        ServiceResponse<Void> result = weimobStoreSiteService.addWeimobGuider(Integer.parseInt(wmMallStoreId),
                Integer.parseInt(enterpriseId), wmGuiderDTO);
        logger.info("异步导购结果：code:{}, message:{}", result.getCode(), result.getMessage());
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<Void> syncClerkToWeimob(Integer wmMallStoreId, String clerkIds, Integer enterpriseId) {
        if (StringUtils.isBlank(clerkIds) || StringUtils.isBlank(clerkIds.replaceAll(GlobalInfo.FLAG_COMMA, ""))) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "参数不存在");
        }
        List<TabClerk> clerkList = clerkService.listClerkByIds(enterpriseId, clerkIds);
        if (CollectionUtils.isNotEmpty(clerkList)) {
            List<Integer> storeInfoIdList = clerkList.stream().map(TabClerk::getStoreInfoId).collect(Collectors.toList());
            Map<String, String> storeInfoIdMapStoreCode = new HashMap<>(16);
            //查询门店，为了获取门店code
            if (CollectionUtils.isNotEmpty(storeInfoIdList)) {
                StoreSearchDbDTO storeSearchDbDTO = new StoreSearchDbDTO();
                storeSearchDbDTO.setStoreInfoIdList(storeInfoIdList);
                com.github.pagehelper.Page<StoreDTO> storePage = storeService.listStore(storeSearchDbDTO, 1, storeInfoIdList.size());
                if (storePage != null) {
                    List<StoreDTO> storeList = storePage.getResult();
                    if (CollectionUtils.isNotEmpty(storeList)) {
                        storeList.forEach( store -> storeInfoIdMapStoreCode.put(store.getStoreInfoId().toString(), store.getStoreName()));
                    }
                }
            }
            clerkList.forEach(clerkTemp -> {
                WeimobGuiderSynDTO weimobGuiderSynDTO = new WeimobGuiderSynDTO();
                weimobGuiderSynDTO.setStoreNumber(storeInfoIdMapStoreCode.get(clerkTemp.getStoreInfoId().toString()));
                weimobGuiderSynDTO.setClerkId(clerkTemp.getClerkId());
                weimobGuiderSynDTO.setGuiderName(clerkTemp.getClerkName());
                weimobGuiderSynDTO.setGuiderPhone(clerkTemp.getPhoneNumber());
                weimobGuiderSynDTO.setJobNumber(clerkTemp.getClerkCode());
                weimobGuiderSynDTO.setStoreInfoId(clerkTemp.getStoreInfoId());
                asynClerkInfoToWeimobMq(wmMallStoreId, enterpriseId, weimobGuiderSynDTO);
            });

        }
        return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "参数错误，导购数据不存在");
    }

    @Override
    public ServiceResponse<Void> syncClerkToWeimobWhenModify(String param) {
        JSONObject jsonObject = JSONObject.parseObject(param);
        String clerkInfo = jsonObject.getString("clerkInfo");
        ClerkDTO clerkDTO = JSONObject.parseObject(clerkInfo, ClerkDTO.class);
        ServiceResponse<StoreDTO> storeResult = storeApiService
                .getStoreByStoreInfoId(clerkDTO.getEnterpriseId(), clerkDTO.getStoreInfoId());
        if (storeResult.isSuccess()) {
            StoreDTO storeDTO = storeResult.getResult();
            ServiceResponse<List<WmStoreSyncLogDTO>> wmStoreListResult = wmStoreSyncLogApiService
                    .listByStoreId(storeDTO.getStoreId(), storeDTO.getEnterpriseId());
            if (wmStoreListResult.isSuccess()) {
                WeimobGuiderSynDTO weimobGuiderSynDTO = new WeimobGuiderSynDTO();
                weimobGuiderSynDTO.setStoreNumber(storeDTO.getStoreCode());
                weimobGuiderSynDTO.setClerkId(clerkDTO.getClerkId());
                weimobGuiderSynDTO.setGuiderName(clerkDTO.getClerkName());
                weimobGuiderSynDTO.setGuiderPhone(clerkDTO.getPhoneNumber());
                weimobGuiderSynDTO.setJobNumber(clerkDTO.getClerkCode());
                weimobGuiderSynDTO.setStoreInfoId(clerkDTO.getStoreInfoId());

                List<WmStoreSyncLogDTO> wmStoreLog = wmStoreListResult.getResult();
                wmStoreLog.forEach(storeLog -> {
                    ServiceResponse<Boolean> isExitClerkResult = weimobStoreSiteService
                            .isExitClerk(storeLog.getWmMallStoreId(), clerkDTO.getPhoneNumber());
                    if (isExitClerkResult.isSuccess()) {
                        ServiceResponse<Void> weimobResult;
                        if (isExitClerkResult.getResult()) {
                            //如果存在了，则是更新操作
                            weimobResult = weimobStoreSiteService
                                    .updateWeimobGuider(storeLog.getWmMallStoreId(), storeLog.getEnterpriseId(), weimobGuiderSynDTO);
                        } else {
                            //新增操作
                            weimobResult = weimobStoreSiteService
                                    .addWeimobGuider(storeLog.getWmMallStoreId(), storeLog.getEnterpriseId(), weimobGuiderSynDTO);
                        }
                        logger.warn("导购增改微盟返回结果:{}", JSONObject.toJSONString(weimobResult));
                    }
                });
            }
        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<List<ClerkDTO>> listHaobanClerk(List<Integer> clerkIdList) {
        List<TabClerk> clerkList = this.clerkService.listClerkByIds(clerkIdList);
        return haobanClerk(clerkList);
    }

    @Override
    public ServiceResponse<List<ClerkDTO>> listHaobanClerk(List<Integer> enterpriseIdList, String keyword, List<Integer> storeInfoIdList) {
        List<TabClerk> clerkList = this.clerkService.listHaobanClerk(enterpriseIdList, keyword, storeInfoIdList);
        return haobanClerk(clerkList);
    }

    @Override
    public ServiceResponse<List<ClerkDTO>> listHaobanClerk(Integer enterpriseId, Integer positionId) {
        List<TabClerk> clerkList = this.clerkService.listClerkByPositionId(enterpriseId, positionId);
        return haobanClerk(clerkList);
    }

    private ServiceResponse<List<ClerkDTO>> haobanClerk(List<TabClerk> clerkList) {
        List<ClerkDTO> clerkDTOS = EntityUtil.changeEntityListByJSON(ClerkDTO.class, clerkList);
        if (CollectionUtils.isNotEmpty(clerkDTOS)) {
            List<Integer> storeInfoIdList = clerkDTOS.stream().map(ClerkDTO::getStoreInfoId).collect(Collectors.toList());
            StoreSearchDbDTO storeSearchDbDTO = new StoreSearchDbDTO();
            storeSearchDbDTO.setStoreInfoIdList(storeInfoIdList);
            com.github.pagehelper.Page<StoreDTO> listStore = storeService.listStore(storeSearchDbDTO, 1, Integer.MAX_VALUE);
            if (CollectionUtils.isNotEmpty(listStore)) {
                Map<Integer, String> map = listStore.getResult().stream().collect(Collectors.toMap(StoreDTO::getStoreInfoId, StoreDTO::getStoreName, (e1, e2) -> e1));
                for (ClerkDTO clerkDTO : clerkDTOS) {
                    clerkDTO.setStoreName(map.get(clerkDTO.getStoreInfoId()));
                }
            }
        }
        return ServiceResponse.success(clerkDTOS);
    }

    private void asynClerkInfoToWeimobMq(Integer wmMallStoreId, Integer enterpriseId, WeimobGuiderSynDTO wmGuiderDTO) {
        GicMQClient client = GICMQClientUtil.getClientInstance();
        Map<String, Object> params = new HashMap<>(4);
        params.put("enterpriseId", enterpriseId);
        params.put("wmMallStoreId", wmMallStoreId);
        params.put("wmGuiderDTO", JSONObject.toJSONString(wmGuiderDTO));

        try {
            client.sendMessage("tmpClerkToWeimob", JSONObject.toJSONString(params));
        } catch (Exception e) {
            logger.warn("同步导购到微盟错误:{}", e.getMessage(), e);
        }
    }

    private static ServiceResponse<String> responseErrorElement(ImportClerkBatchResultEnum error) {
        logger.warn("批处理导购错误返回结果:{}", error.toString());
        return ServiceResponse.failure(error.getCode(), error.toString());
    }


    private void synClerkInfoToWeimobMq(ClerkDTO powerClerkDTO) {
        GicMQClient client = GICMQClientUtil.getClientInstance();
        Map<String, Object> params = new HashMap<>(4);
        params.put("clerkInfo", JSONObject.toJSONString(powerClerkDTO));
        try {
            logger.info("导购增改微盟参数:{}", JSONObject.toJSONString(params));
            client.sendMessage("synClerkInfoToWeimobMq", JSONObject.toJSONString(params));
        } catch (Exception e) {
            logger.warn("exception", e);
        }
    }

}