package com.gic.store.service.outer.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.bizdict.api.dto.BizdictDTO;
import com.gic.bizdict.api.service.BizdictService;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.response.EnterpriseServiceResponse;
import com.gic.redis.data.util.RedisUtil;
import com.gic.store.constant.Constants;
import com.gic.store.constant.StoreFieldTypeEnum;
import com.gic.store.dto.StoreDictDTO;
import com.gic.store.dto.StoreFieldDTO;
import com.gic.store.entity.TabStoreDict;
import com.gic.store.entity.TabStoreField;
import com.gic.store.service.StoreDictApiService;
import com.gic.store.service.StoreDictService;
import com.gic.store.service.StoreFieldApiService;
import com.gic.store.service.StoreFieldService;
import com.gic.store.utils.StoreRedisKeyUtils;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;
/**
 * 
 * @ClassName: StoreDictApiServiceImpl
 * @Description:  
 * @author zhiwj
 * @date 2020-09-09 17:53
 */
@Service("storeDictApiService")
public class StoreDictApiServiceImpl implements StoreDictApiService {

    private Logger logger = LogManager.getLogger(StoreDictApiServiceImpl.class);

    @Autowired
    private StoreDictService storeDictService;
    @Autowired
    private BizdictService bizdictService;
    @Autowired
    private StoreFieldService storeFieldService;
    @Autowired
    private StoreFieldApiService storeFieldApiService;

    @Override
    public ServiceResponse<List<StoreDictDTO>> listAllBusinessCategory(Integer enterpriseId) {
        List<StoreDictDTO> result = new ArrayList<>();
        List<BizdictDTO> list = this.bizdictService.treeByCategoryCode("businessCategory");
        if(CollectionUtils.isNotEmpty(list)){
            result = changeListToTree(list, enterpriseId);
        }
        return ServiceResponse.success(result);
    }

    @Override
    public ServiceResponse<StoreDictDTO> getStoreDict(String categoryCode, String code) {
        BizdictDTO dto = this.bizdictService.getByCode(categoryCode, code);
        StoreDictDTO storeDictDTO = new StoreDictDTO();
        storeDictDTO.setKey(dto.getName());
        storeDictDTO.setValue(dto.getValueContent());
        return EnterpriseServiceResponse.success(storeDictDTO);
    }

    private List<StoreDictDTO> changeListToTree(List<BizdictDTO> list, Integer enterpriseId) {
        List<StoreDictDTO> result = new ArrayList<>();
        for(BizdictDTO bizdictDTO : list){
            StoreDictDTO dictDTO = new StoreDictDTO();
            dictDTO.setEnterpriseId(enterpriseId);
            dictDTO.setKey(bizdictDTO.getName());
            dictDTO.setValue(bizdictDTO.getValueContent());
            if (CollectionUtils.isNotEmpty(bizdictDTO.getNodeChildren())) {
                List nodeChildren = bizdictDTO.getNodeChildren();
                List<StoreDictDTO> dtoList = changeListToTree((List<BizdictDTO>) nodeChildren, enterpriseId);
                dictDTO.setStoreDictList(dtoList);
            }
            result.add(dictDTO);
        }
        return result;
    }

    @Override
    public ServiceResponse<List<StoreDictDTO>> listAllStoreType(Integer enterpriseId) {
        return ServiceResponse.success(this.listAllStoreDict(enterpriseId, "storeType"));
    }

    @Override
    public ServiceResponse<List<StoreDictDTO>> listAllStoreStatus(Integer enterpriseId) {
        return ServiceResponse.success(this.listAllStoreDict(enterpriseId, "storeStatus"));
    }

    @Override
    public ServiceResponse<List<StoreDictDTO>> listStoreType(Integer enterpriseId) {
        return ServiceResponse.success(this.listStoreDict(enterpriseId, "storeType"));
    }

    @Override
    public ServiceResponse<List<StoreDictDTO>> listStoreStatus(Integer enterpriseId) {
        return ServiceResponse.success(this.listStoreDict(enterpriseId, "storeStatus"));
    }

    @Override
    public ServiceResponse saveStoreType(Integer enterpriseId, String[] storeTypeArr) {
        boolean valid = enterpriseId == null || storeTypeArr == null || (storeTypeArr != null && storeTypeArr.length == 0);
        if(valid){
            return ServiceResponse.failure(ErrorCode.MISS_PARAMETER.getCode(), ErrorCode.MISS_PARAMETER.getMsg());
        }
        List<String> listSelected = this.storeDictService.listStoreType(enterpriseId);
        List<String> list = Arrays.asList(storeTypeArr);
        List<String> delList = listSelected.stream().filter(s -> !list.contains(s)).collect(Collectors.toList());
        delList.forEach(s ->{
            this.storeDictService.deleteStoreDict(enterpriseId, s, "storeType");
        });
        for(String storeType : storeTypeArr){
            boolean isExist = false;
            for(String s : listSelected){
                if(s.equals(storeType)){
                    isExist = true;
                }
            }
            if(!isExist && StringUtils.isNotBlank(storeType)){
                TabStoreDict tabStoreDict = new TabStoreDict();
                tabStoreDict.setEnterpriseId(enterpriseId);
                tabStoreDict.setCreateTime(new Date());
                tabStoreDict.setValue(storeType);
                this.storeDictService.saveStoreType(tabStoreDict);
            }
        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse saveStoreStatus(Integer enterpriseId, String[] storeStatusArr) {
        boolean valid = enterpriseId == null || storeStatusArr == null || (storeStatusArr != null && storeStatusArr.length == 0);
        if(valid){
            return ServiceResponse.failure(ErrorCode.MISS_PARAMETER.getCode(), ErrorCode.MISS_PARAMETER.getMsg());
        }
        List<String> listSelected = this.storeDictService.listStoreStatus(enterpriseId);
        List<String> list = Arrays.asList(storeStatusArr);
        List<String> delList = listSelected.stream().filter(s -> !list.contains(s)).collect(Collectors.toList());
        delList.forEach(s ->{
            this.storeDictService.deleteStoreDict(enterpriseId, s, "storeStatus");
        });
        for(String storeStatus : storeStatusArr){
            boolean isExist = false;
            for(String s : listSelected){
                if(s.equals(storeStatus)){
                    isExist = true;
                }
            }
            if(!isExist && StringUtils.isNotBlank(storeStatus)){
                TabStoreDict tabStoreDict = new TabStoreDict();
                tabStoreDict.setEnterpriseId(enterpriseId);
                tabStoreDict.setCreateTime(new Date());
                tabStoreDict.setValue(storeStatus);
                this.storeDictService.saveStoreStatus(tabStoreDict);
            }
        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse saveStoreStatusAndStoreType(Integer enterpriseId, String[] storeStatusArr, String[] storeTypeArr) {
        this.saveStoreType(enterpriseId, storeTypeArr);
        this.saveStoreStatus(enterpriseId, storeStatusArr);
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse saveStoreStatusAndStoreTypeCallback(String json) {
        JSONObject jsonObject = JSON.parseObject(json);
        logger.info("审批回调结果：{}", json);
        // 审批结果  1:通过    2:不通过
        Integer auditResult = jsonObject.getInteger("auditResult");

        if (Integer.valueOf(1).equals(auditResult)) {
            // 审批通过
            ServiceResponse serviceResponse = saveStoreStatusAndStoreType(
                    jsonObject.getInteger("enterpriseId"), jsonObject.getString("storeStatus").split(","), jsonObject.getString("storeType").split(","));
        }

        return ServiceResponse.failure(ErrorCode.OPERATION_FAILED.getCode(), "审批未通过");
    }

    @Override
    public ServiceResponse<List<StoreDictDTO>> listStoreField(Integer enterpriseId) {
        return listStoreField(enterpriseId, false);
    }

    @Override
    public ServiceResponse<List<StoreDictDTO>> listStoreFieldOfFilterText(Integer enterpriseId) {
        return listStoreField(enterpriseId, true);
    }

    @Override
    public ServiceResponse saveStoreField(Integer enterpriseId, String value, int type, Integer userId) {
        String key = StoreRedisKeyUtils.getStoreFieldKey(enterpriseId, Integer.valueOf(value));
        String keyc = StoreRedisKeyUtils.getStoreFieldKeyC(enterpriseId, "");
        if(type == 1){ //新增

        }else {

        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse saveStoreField(Integer enterpriseId, String values, Integer userId) {
        String keyc = StoreRedisKeyUtils.getStoreFieldKeyC(enterpriseId, "");
        List<String> existList = this.storeDictService.listStoreField(enterpriseId);
        List<String> newList = Arrays.asList(values.split(","));
        List<String> add = newList.stream().filter(s -> !existList.contains(s)).collect(Collectors.toList());
        List<String> del = existList.stream().filter(s -> !newList.contains(s)).collect(Collectors.toList());
        if(CollectionUtils.isNotEmpty(add)){
            add.forEach(s -> {
                if(StringUtils.isBlank(s)){
                    return;
                }
                TabStoreField tabStoreField = this.storeFieldService.getStoreFieldById(Integer.valueOf(s));
                if(tabStoreField.getStoreFieldType() != null && tabStoreField.getStoreFieldType().intValue() == 1){
                    return;
                }
                TabStoreDict tabStoreDict = new TabStoreDict();
                tabStoreDict.setEnterpriseId(enterpriseId);
                tabStoreDict.setCreateTime(new Date());
                tabStoreDict.setValue(s);
                this.storeDictService.saveStoreField(tabStoreDict);
                String key = StoreRedisKeyUtils.getStoreFieldKey(enterpriseId, Integer.valueOf(s));
                Object existObj = RedisUtil.getCache(key);
                if(existObj == null){
                    for(int i = 1; i<= Constants.STORE_EXPORT_SIZE; i++){
                        Object obj = RedisUtil.getCache(keyc+"c"+i);
                        if(obj == null){
                            RedisUtil.setCache(keyc+"c"+i, s);
                            RedisUtil.setCache(key, "c"+i);
                            break;
                        }
                    }
                }
            });
        }
        if(CollectionUtils.isNotEmpty(del)){
            del.forEach(s -> {
                if(StringUtils.isBlank(s)){
                    return;
                }
                String key = StoreRedisKeyUtils.getStoreFieldKey(enterpriseId, Integer.valueOf(s));
                this.storeDictService.deleteStoreDict(enterpriseId, s, "storeField");
                Object c = RedisUtil.getCache(key);
                String storeListSourceKey = StoreRedisKeyUtils.getStoreListSourceKey(enterpriseId, userId);
                if(c != null){
                    RedisUtil.delCache(c.toString());
                    //门店列表自定义字段配置，取消时需要删除当前已经配置的列表显示字段
                    Object storeListSource = RedisUtil.getCache(storeListSourceKey);
                    if(storeListSource != null){
                        String[] arr = storeListSource.toString().split(",");
                        String result = "";
                        for(String a : arr){
                            if(!c.toString().equals(a)){
                                result += a+",";
                            }
                        }
                        if(StringUtils.isNotBlank(result)){
                            RedisUtil.setCache(storeListSourceKey, result);
                        }
                    }
                }
                RedisUtil.delCache(key);
            });
        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<List<String>> listStoreFieldDictValue(Integer enterpriseId) {
        return ServiceResponse.success(this.storeDictService.listStoreField(enterpriseId));
    }

    private List<StoreDictDTO> listAllStoreDict(Integer enterpriseId, String type){
        List<StoreDictDTO> result = new ArrayList<>();
        List<BizdictDTO> list = this.bizdictService.treeByCategoryCode(type);
        if(CollectionUtils.isNotEmpty(list)){
            List<String> listSelected = new ArrayList<>();
            if(Constants.STORE_TYPE.equals(type)){
                listSelected = this.storeDictService.listStoreType(enterpriseId);
            }else{
                listSelected = this.storeDictService.listStoreStatus(enterpriseId);
            }
            for(BizdictDTO bizdictDTO : list){
                StoreDictDTO dictDTO = new StoreDictDTO();
                dictDTO.setEnterpriseId(enterpriseId);
                dictDTO.setKey(bizdictDTO.getName());
                dictDTO.setValue(bizdictDTO.getValueContent());
                for(String s : listSelected){
                    if(s.equals(bizdictDTO.getValueContent())){
                        dictDTO.setChecked(1);
                    }
                }
                result.add(dictDTO);
            }
        }
        return result;
    }

    private List<StoreDictDTO> listStoreDict(Integer enterpriseId, String type){
        List<StoreDictDTO> result = new ArrayList<>();
        List<BizdictDTO> list = this.bizdictService.treeByCategoryCode(type);
        if(CollectionUtils.isNotEmpty(list)){
            List<String> listSelected = new ArrayList<>();
            if(Constants.STORE_TYPE.equals(type)){
                listSelected = this.storeDictService.listStoreType(enterpriseId);
            }else{
                listSelected = this.storeDictService.listStoreStatus(enterpriseId);
            }
            for(BizdictDTO bizdictDTO : list){
                for(String s : listSelected){
                    if(s.equals(bizdictDTO.getValueContent())){
                        StoreDictDTO dictDTO = new StoreDictDTO();
                        dictDTO.setEnterpriseId(enterpriseId);
                        dictDTO.setKey(bizdictDTO.getName());
                        dictDTO.setValue(bizdictDTO.getValueContent());
                        dictDTO.setChecked(1);
                        result.add(dictDTO);
                    }
                }
            }
        }
        return result;
    }

    private ServiceResponse<List<StoreDictDTO>> listStoreField(Integer enterpriseId, boolean isFilterTextField) {
        List<StoreDictDTO> result = new ArrayList<>();
        ServiceResponse<List<StoreFieldDTO>> listStoreField = storeFieldApiService.listStoreField(enterpriseId, null);
        if(listStoreField.isSuccess()){
            List<StoreFieldDTO> list = listStoreField.getResult();
            List<String> listSelect = this.storeDictService.listStoreField(enterpriseId);
            for(StoreFieldDTO tabStoreField : list){
                if (isFilterTextField) {
                    //过滤文本自定义字段
                    if (tabStoreField.getStoreFieldType().intValue() == StoreFieldTypeEnum.TEXT.getCode()) {
                        continue;
                    }
                }
                StoreDictDTO storeDictDTO = new StoreDictDTO();
                storeDictDTO.setKey(tabStoreField.getStoreFieldName());
                storeDictDTO.setValue(tabStoreField.getStoreFieldId()+"");
                storeDictDTO.setOwnType(tabStoreField.getOwnType());
                for(String s : listSelect){
                    if(tabStoreField.getStoreFieldId().intValue() == Integer.valueOf(s).intValue()){
                        storeDictDTO.setChecked(1);
                    }
                }
                result.add(storeDictDTO);
            }
        }
        return ServiceResponse.success(result);
    }
}
