package com.gic.store.service.outer.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.util.GlobalInfo;
import com.gic.store.constant.*;
import com.gic.store.dto.*;
import com.gic.store.entity.*;
import com.gic.store.service.*;
import com.gic.store.utils.baidumap.BaiduMapUtils;
import com.gic.store.utils.baidumap.Location;
import com.github.pagehelper.Page;
import com.task.allocation.api.AbstractTaskAllocationOperation;
import com.task.allocation.exception.TaskAllocationException;
import com.task.allocation.qo.InitTaskQO;
import com.task.allocation.util.TaskAllocationSdkClient;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.Optional;
import java.util.stream.Collectors;

/**
 * @author zhiwj
 * @date 2019/7/4
 */
@Service("storeTaskApiService")
public class StoreTaskServiceImpl extends AbstractTaskAllocationOperation implements StoreTaskApiService {

    private static final Logger logger = LogManager.getLogger(StoreTaskServiceImpl.class);

    @Autowired
    private StoreImportService storeImportService;

    @Autowired
    private StoreBrandService storeBrandService;

    @Autowired
    private ProvincesApiService provincesApiService;

    @Autowired
    private StoreDictApiService storeDictApiService;

    @Autowired
    private StoreGroupService storeGroupService;

    @Autowired
    private StoreApiService storeApiService;

    @Autowired
    private StoreService storeService;

    @Autowired
    private StoreStrategyApiService storeStrategyApiService;

    @Autowired
    private StoreStrategyService storeStrategyService;

    @Autowired
    private StoreFieldService storeFieldService;

    @Autowired
    private StoreFieldSelectService storeFieldSelectService;

    @Override
    public List<Object> getListTasks(String params) {
        JSONObject json = (JSONObject) JSON.parse(params);
        String enterpriseId = json.getString("enterpriseId");
        boolean isReplace = json.getBoolean("isReplace");
        List<TabStoreTmp> list = storeImportService.listUnImportStore(enterpriseId);
        logger.info("门店批量导入放入队列数据数量：{}", list.size());

        List<StoreTmpDTO> taskList = EntityUtil.changeEntityListByOrika(StoreTmpDTO.class, list);
        if (CollectionUtils.isNotEmpty(taskList)) {
            for (StoreTmpDTO dto : taskList) {
                dto.setReplace(isReplace);
            }
        }
        List listTask = taskList;
        return listTask;
    }

    @Override
    public void dealSingle(Object o) throws TaskAllocationException {
        logger.info("开始执行队列");
        StoreTmpDTO t = (StoreTmpDTO) o;
        try {
            this.importDataToStore(t);
        } catch (Exception e) {
            logger.warn("写入门店表和成员表异常", e);
            t.setErrorMessage("导入异常");
            storeImportService.updateData(t);
        }
    }

    public void importDataToStore(StoreTmpDTO t) {
        logger.info("开始执行队列:id ==>{}", t.getStoreTmpId());
        StoreDTO storeDTO = new StoreDTO();
        storeDTO.setEnterpriseId(t.getEnterpriseId());
        storeDTO.setStoreName(t.getStoreName());
        // 设置创建类型
        storeDTO.setCreateType(CreateTypeEnum.BATCH_IMPORT.getCode());
        // 判断code是否重复
        Integer storeId = storeService.validateStoreCodeIsExist(t.getEnterpriseId(), t.getRegionId(), t.getStoreCode());
        if (storeId != null) {
            if (t.isReplace()) {
                //替换更新code重复的记录
                storeDTO.setStoreId(storeId);
            } else {
                t.setErrorMessage("门店code已经存在");
                storeImportService.updateData(t);
                return;
            }
        }
        storeDTO.setStoreCode(t.getStoreCode().trim());
        storeDTO.setRegionId(t.getRegionId());
        storeDTO.setConactsPhone(t.getConactsPhone().trim());
        storeDTO.setAddress(t.getAddress().trim());
        // 判断门店品牌
        String brands = t.getBrands();
        if (StringUtils.isNotBlank(brands)) {
            TabStoreBrand storeBrand = storeBrandService.getByStoreBrandName(t.getEnterpriseId(), brands);
            storeDTO.setBrandIds(storeBrand.getStoreBrandId().toString());
        }
        // 地址类信息
        parseArea(t, storeDTO);
        // todo 判断溢出
        storeDTO.setOverflowStatus(0);
        praseErpStatusAndStoreType(t, storeDTO);
        if (StringUtils.isNotBlank(t.getStoreGroupName())) {
            storeDTO.setIsEditStoreGroup(1);
            TabStoreGroup group = storeGroupService.getStoreGroupByName(t.getStoreGroupName(), t.getEnterpriseId());
            if (group != null) {
                storeDTO.setStoreGroupId(group.getStoreGroupId());
            } else {
                t.setErrorMessage("分组不存在");
                storeImportService.updateData(t);
                logger.info("enterpriseId:{}, groupName:{}, 不存在该分组", t.getEnterpriseId(), t.getStoreGroupName());
                return;
            }
        } else {
            storeDTO.setIsEditStoreGroup(0);
        }
        logger.info("storeDTO:{}", JSON.toJSONString(storeDTO));
        // 启用策略
        String hitStrategy = storeStrategyService.isHitStrategy(storeDTO, StoreGroupConstant.STORE_STRATEGY_TYPE);
        storeDTO.setStatus(StringUtils.isNotBlank(hitStrategy) ? Integer.valueOf(hitStrategy) : StoreEnableOrDisAbleEnum.DISABLE.getCode());
        storeDTO.setCreateTime(new Date());
        storeDTO.setCreateType(CreateTypeEnum.BATCH_IMPORT.getCode());
        //  扩展信息
        List<StoreExtendDTO> extendList = getStoreExtendDTOList(t);
        storeDTO.setStoreExtendList(extendList);
        storeDTO.setReason(StoreLogReasonEnum.WEB.getCode());
        storeDTO.setRemark("批量导入");
        storeDTO.setOperatorId(t.getOperatorId());
        storeDTO.setOperatorName(t.getOperatorName());
        ServiceResponse<StoreDTO> serviceResponse = storeApiService.saveOrUpdate(storeDTO);
        String msg;
        if (serviceResponse.isSuccess()) {
            msg = StoreImportEnum.SUCCESS.getCode();
        } else {
            msg = serviceResponse.getMessage();
        }
        t.setErrorMessage(msg);
        storeImportService.updateData(t);
    }

    private void praseErpStatusAndStoreType(StoreTmpDTO t, StoreDTO storeDTO) {
        if (StringUtils.isNotBlank(t.getErpStatus())) {
            ServiceResponse<List<StoreDictDTO>> erpStatusResponse = storeDictApiService.listStoreStatus(t.getEnterpriseId());
            List<StoreDictDTO> erpList = erpStatusResponse.getResult();
            final String erpStatusTmp = t.getErpStatus().replace("\\s+", "");
            Optional<StoreDictDTO> erpStatusDTO = erpList.stream().filter(e -> e.getKey().equals(erpStatusTmp)).findFirst();
            storeDTO.setErpStatus(Integer.parseInt(erpStatusDTO.get().getValue()));
        }
        if (StringUtils.isNotBlank(t.getStoreType())) {
            ServiceResponse<List<StoreDictDTO>> storeTypeResponse = storeDictApiService.listStoreType(t.getEnterpriseId());
            List<StoreDictDTO> typeList = storeTypeResponse.getResult();
            final String typeTmp = t.getStoreType().replace("\\s+", "");
            Optional<StoreDictDTO> typeTmpDTO = typeList.stream().filter(e -> e.getKey().equals(typeTmp)).findFirst();
            storeDTO.setStoreType(Integer.parseInt(typeTmpDTO.get().getValue()));
        }
    }

    private void parseArea(StoreTmpDTO t, StoreDTO storeDTO) {
        // 判断省市区
        ServiceResponse<List<CityDTO>> cityResponse = provincesApiService.selectAllCity();
        ServiceResponse<List<CountyDTO>> countyResponse = provincesApiService.selectAllCounty();
        ServiceResponse<List<ProvinceDTO>> provinceResponse = provincesApiService.selectAllProvince();
        StringBuilder address = new StringBuilder();
        if (StringUtils.isNotBlank(t.getProvince().trim())) {
            List<ProvinceDTO> provinceDTOList = provinceResponse.getResult();
            Optional<ProvinceDTO> provinceDTO = provinceDTOList.stream().filter(e -> StringUtils.equals(e.getProvinceName(), t.getProvince())).findFirst();
            storeDTO.setProvinceId(provinceDTO.get().getProvinceId());
            address.append(provinceDTO.get().getProvinceName()).append("/");
        }
        if (StringUtils.isNotBlank(t.getCity().trim())) {
            List<CityDTO> cityDTOList = cityResponse.getResult();
            Optional<CityDTO> cityDTO = cityDTOList.stream().filter(e -> StringUtils.equals(e.getCityName(), t.getCity())).findFirst();
            storeDTO.setCityId(cityDTO.get().getCityId());
            address.append(cityDTO.get().getCityName()).append("/");
        }
        if (StringUtils.isNotBlank(t.getCounty().trim())) {
            List<CountyDTO> countyDTOList = countyResponse.getResult();
            Optional<CountyDTO> countyDTO = countyDTOList.stream().filter(e -> StringUtils.equals(e.getCountyName(), t.getCounty())).findFirst();
            storeDTO.setAreaId(countyDTO.get().getCountyId());
            address.append(countyDTO.get().getCountyName());
        }
        String addressStr = address.toString();
        storeDTO.setProvinces(addressStr.trim());
        if (StringUtils.isBlank(t.getLongitude()) && StringUtils.isBlank(t.getLatitude()) && StringUtils.isNotBlank(addressStr)) {
            Location location = BaiduMapUtils.get(addressStr.replace("/", ""));
            if (location != null) {
                storeDTO.setLongitude(location.getLng());
                storeDTO.setLatitude(location.getLat());
            }
        } else {
            storeDTO.setLongitude(t.getLongitude());
            storeDTO.setLatitude(t.getLatitude());
        }
        // 经纬度校验
        if (StringUtils.isNotBlank(storeDTO.getLongitude())) {
            try {
                Float.valueOf(storeDTO.getLongitude());
            } catch (NumberFormatException e) {
                t.setErrorMessage("经度错误");
            }
        }
        if (StringUtils.isNotBlank(storeDTO.getLatitude())) {
            try {
                Float.valueOf(storeDTO.getLatitude());
            } catch (NumberFormatException e) {
                t.setErrorMessage("维度错误");
            }
        }
    }

    private List<StoreExtendDTO> getStoreExtendDTOList(StoreTmpDTO t) {
        String customField = t.getCustomField();
        List<StoreExtendDTO> extendList = JSON.parseArray(customField, StoreExtendDTO.class);
        for (StoreExtendDTO storeExtendDTO : extendList) {
            TabStoreField field = storeFieldService.getStoreFieldById(storeExtendDTO.getStoreFieldId());
            if (StoreFieldTypeEnum.RADIO.getCode() == field.getStoreFieldType() || StoreFieldTypeEnum.CHECK.getCode() == field.getStoreFieldType()) {
                if (StringUtils.isNotBlank(storeExtendDTO.getValue())) {
                    String[] valueArr = storeExtendDTO.getValue().split(GlobalInfo.FLAG_COMMA);
                    Page<TabStoreFieldSelect> fieldSelects = storeFieldSelectService.listStoreFieldSelect(storeExtendDTO.getStoreFieldId(), null, 1, Integer.MAX_VALUE);
                    String newValue = fieldSelects.stream()
                            .filter(e -> {
                                for (String value : valueArr) {
                                    if (e.getStoreFieldSelectName().equals(value)) {
                                        return true;
                                    }
                                }
                                return false;
                            })
                            .map(e -> e.getStoreFieldSelectId() + "")
                            .collect(Collectors.joining(","));
                    storeExtendDTO.setValue(newValue);
                }
            }
        }
        return extendList;
    }

    @Override
    public String importDataToStore(Integer enterpriseId, String userId, String uuId, boolean isReplace) {
        logger.info("enterpriseId:{}, userId:{}, uuId:{}", enterpriseId, userId, uuId);
        String message = "";
        InitTaskQO initTaskQo = new InitTaskQO();
        initTaskQo.setEnterpriseId(enterpriseId.toString());// 企业id
        initTaskQo.setOperationUserId(userId);// 操作人id
        initTaskQo.setTaskMqKey(Constants.STORE_BATCH_IMPORT_MQ_KEY);// 注册的队列名称
        initTaskQo.setTaskType(Constants.STORE_BATCH_IMPORT_TASK_TYPE);// 任务类型
        initTaskQo.setTaskSignKey(uuId);// 任务类型 唯一标识符

        JSONObject params = new JSONObject();
        //如果门店code重复，是否替换更新
        params.put("isReplace", isReplace);
        params.put("enterpriseId", enterpriseId);
        initTaskQo.setParams(params.toString());
        try {
            TaskAllocationSdkClient instance = TaskAllocationSdkClient.getInstance();// 初始化sdk
            instance.initTask(initTaskQo);// 初始化接口
            logger.info("门店批量导入队列初始化成功");
        } catch (Exception e) {
            logger.warn("门店批量导入队列初始化异常", e);
            message = "门店批量导入队列初始化异常";
        }
        return message;
    }
}
