package com.gic.store.strategy.impl;

import com.gic.member.config.api.dto.UserOwnerDefaultDTO;
import com.gic.member.config.api.service.CardAscriptionConfigService;
import com.gic.spark.api.service.SparkJobApiService;
import com.gic.store.constant.Constants;
import com.gic.store.constant.StoreStatusEnum;
import com.gic.store.dto.StoreDTO;
import com.gic.store.dto.StoreSearchDbDTO;
import com.gic.store.service.ClerkService;
import com.gic.store.service.StoreLogService;
import com.gic.store.service.StoreService;
import com.gic.store.strategy.BulkUpdateStoreStrtegy;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 
 * @ClassName: StoreStatusStrategyImpl
 * @Description:  
 * @author zhiwj
 * @date 2020-09-09 17:54
 */
@Component("1")
public class StoreStatusStrategyImpl implements BulkUpdateStoreStrtegy {

    @Autowired
    private StoreLogService storeLogService;
    @Autowired
    private SparkJobApiService sparkJobApiService;
    @Autowired
    private CardAscriptionConfigService cardAscriptionConfigService;
    @Autowired
    private ClerkService clerkService;
    @Autowired
    private StoreService storeService;

    @Override
    public String bulkUpdateStore(String storeInfoIds, Integer enterpriseId, String value, StoreService storeService, Integer operatorId, String operatorName) {
        List<Integer> storeInfoIdList = new ArrayList<>();
        List<UserOwnerDefaultDTO> result = this.cardAscriptionConfigService.getDefaultUserOwner(enterpriseId).getResult();
        if (Constants.ALL.equals(storeInfoIds)) {
            storeInfoIdList = storeService.listAllStoreInfoId(enterpriseId);
        } else {
            storeInfoIdList = new ArrayList<>();
            String[] storeIdArr = storeInfoIds.split(",");
            for (String s : storeIdArr) {
                storeInfoIdList.add(Integer.valueOf(s));
            }
        }
        if(CollectionUtils.isNotEmpty(result) && StoreStatusEnum.INONLINE.getCode() == Integer.valueOf(value)){
            storeInfoIdList = storeInfoIdList.stream().filter(storeInfoId -> {
                for(UserOwnerDefaultDTO dto : result){
                    if(storeInfoId.intValue() == dto.getStoreInfoId().intValue()){
                        return false;
                    }
                }
                return true;
            }).collect(Collectors.toList());
        }
        if(CollectionUtils.isNotEmpty(storeInfoIdList)){
            int valueCode = Integer.parseInt(value);
            String errorMsg = null;
            if (StoreStatusEnum.ONLINE.getCode() == valueCode) {
                // 改成启用 需要判断门店下有没有导购 没有导购不能启用  先查出来有导购的门店
                List<Integer> storeInfoIdListNew = clerkService.listStoreInfoIdByStoreInfoId(enterpriseId, storeInfoIdList);
                if (CollectionUtils.isEmpty(storeInfoIdListNew)) {
                    // 每个门店下都没有导购
                    return getStoreHasNotClerkMsg(enterpriseId, storeInfoIdList, storeInfoIdListNew);
                } else if (storeInfoIdListNew.size() == storeInfoIdList.size()) {
                    // 每个门店下都有导购
                    errorMsg = null;
                } else {
                    errorMsg = getStoreHasNotClerkMsg(enterpriseId, storeInfoIdList, storeInfoIdListNew);
                    storeInfoIdList = storeInfoIdListNew;
                }

            }
            String storeInfoIdsNew = StringUtils.join(storeInfoIdList, ",");
            int i = storeService.bulkUpdateStoreStatus(storeInfoIdsNew, enterpriseId, value);
            if (i > 0) {
                storeLogService.saveBulkStoreStatusLog(storeInfoIdList, enterpriseId, operatorId, operatorName, "门店状态变更为【" + StoreStatusEnum.parseCode(valueCode) + "】");
                for (Integer storeInfoId : storeInfoIdList) {
                    // 启用禁用的值和会员组取的不一致 需要转换下
                    sparkJobApiService.updateStoreStatus(enterpriseId, storeInfoId, StoreStatusEnum.ONLINE.getCode() == valueCode ? 0 : 1);

                }
            }
            return errorMsg;
        }
        return null;
    }

    private String getStoreHasNotClerkMsg(Integer enterpriseId, List<Integer> storeInfoIdList, List<Integer> storeInfoIdListNew) {
        // 没有导购的门店
        List<Integer> storeInfoIdHasNotClerkMsgList;


        if (CollectionUtils.isNotEmpty(storeInfoIdListNew)) {
            storeInfoIdHasNotClerkMsgList = storeInfoIdList.stream().filter(e -> !storeInfoIdListNew.contains(e)).collect(Collectors.toList());
        } else {
            storeInfoIdHasNotClerkMsgList = storeInfoIdList;
        }
        StoreSearchDbDTO storeSearchDbDTO = new StoreSearchDbDTO();
        storeSearchDbDTO.setEnterpriseId(enterpriseId);
        storeSearchDbDTO.setStoreInfoIdList(storeInfoIdHasNotClerkMsgList);
        String msg = storeService.listStore(storeSearchDbDTO, 1, Integer.MAX_VALUE).stream().map(StoreDTO::getStoreName).collect(Collectors.joining(","));

        return String.format("共选中%d家门店，%d家成功启用，%s下无可用导购，无法启用门店，请在门店下至少新建或启用一个导购",
                storeInfoIdList.size(),
                CollectionUtils.isNotEmpty(storeInfoIdListNew) ? storeInfoIdListNew.size() : 0,
                msg
                );
    }
}
