package com.gic.store.web.controller;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.auth.dto.MenuDTO;
import com.gic.auth.service.MenuApiService;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.download.constants.QrcodeTypeEnum;
import com.gic.download.qo.QrcodeContent;
import com.gic.download.utils.*;
import com.gic.download.utils.log.LogUtils;
import com.gic.enterprise.constants.Constants;
import com.gic.enterprise.context.RequestContext;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.service.DownloadReportApiService;
import com.gic.enterprise.service.QrCodeApiService;
import com.gic.enterprise.utils.ResultControllerUtils;
import com.gic.enterprise.utils.UserDetailUtils;
import com.gic.store.constant.ClerkLogReasonEnum;
import com.gic.store.dto.ClerkDTO;
import com.gic.store.dto.ClerkLogDTO;
import com.gic.store.dto.ClerkSearchDTO;
import com.gic.store.dto.ClerkStoreListDTO;
import com.gic.store.service.ClerkApiService;
import com.gic.store.service.ClerkLogApiService;
import com.gic.store.web.qo.PageQO;
import com.gic.store.web.qo.clerk.ClerkQO;
import com.gic.store.web.qo.store.ClerkQrcodeQO;
import com.gic.wechat.business.api.service.fwh.WeixinBaseFunService;
import com.gic.wechat.business.api.service.wxa.WeixinWxaFunService;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @author zhiwj
 * @date 2019/7/16
 */
@RestController
public class ClerkController extends DownloadUtils {

    private Logger logger = LogManager.getLogger(ClerkController.class);

    @Autowired
    private ClerkApiService clerkApiService;
    @Autowired
    private ClerkLogApiService clerkLogApiService;
    @Autowired
    private MenuApiService menuApiService;
    @Autowired
    private QrCodeApiService qrCodeApiService;
    @Autowired
    private WeixinBaseFunService weixinBaseFunService;
    @Autowired
    private WeixinWxaFunService weixinWxaFunService;
    @Autowired
    private DownloadReportApiService downloadReportApiService;

    @RequestMapping("/list-clerk-field")
    public RestResponse listClerkField() {
        ClerkFiledEnum[] values = ClerkFiledEnum.values();
        List<Map<String, Object>> arrayList = new ArrayList<>(values.length);
        for (ClerkFiledEnum value : values) {
            Map<String, Object> hashMap = new HashMap<>(4);
            hashMap.put("fieldCode", value.getFieldCode());
            hashMap.put("fieldName", value.getFieldName());
            hashMap.put("needEncrypt", value.getNeedEncrypt());
            arrayList.add(hashMap);
        }
        return RestResponse.success(arrayList);
    }

    @RequestMapping("/export-clerk")
    public RestResponse exportClerk(HttpServletRequest request, @RequestBody ClerkSearchDTO clerkSearchDTO) {
        clerkSearchDTO.setEnterpriseId(UserDetailUtils.getUserDetail().getEnterpriseId());
        ServiceResponse<Integer> totalClerkServiceResponse = clerkApiService.getTotalClerk(UserDetailUtils.getUserDetail().getEnterpriseId(), clerkSearchDTO);
        if (totalClerkServiceResponse.getResult() == 0) {
            return RestResponse.failure(ErrorCode.NOTEXISTS.getCode(), ErrorCode.NOTEXISTS.getMsg());
        }

        List<String> fieldCodeList = clerkSearchDTO.getFieldCodeList();
        List<String> fieldNameList = new ArrayList<>(fieldCodeList.size());
        for (String fieldCode: fieldCodeList) {
            String fieldName = ClerkFiledEnum.valueOf(fieldCode).getFieldName();
            fieldNameList.add(fieldName);
        }


        // 开始下载
        String dataContent = getDataContent();

        // 生成入参数据
        DownloadReport report = new DownloadReport();
        //申请人ID
        report.setApplyUserId(UserDetailUtils.getUserDetail().getUserId());
        //数据源（频道页），用  "-" 隔开上级和本级
        report.setDataContent(dataContent);
        //待下载数据的数据总量
        report.setDataCount(totalClerkServiceResponse.getResult());
        //报告类型  1：完整数据， 2：脱敏数据， 3：二维码
        report.setDataType(clerkSearchDTO.getDataType());
        //数据源超链接，用于点击跳转对应频道页面
        report.setDataUrl((String) RequestContext.getContext().getRequest().getAttribute("moduleMenuUrl"));
        report.setEnterpriseId(UserDetailUtils.getUserDetail().getEnterpriseId());
        //待下载文件名
        report.setFileName(clerkSearchDTO.getFileName());
        //待下载数据的结束时间
        report.setReportEndTime(null);
        //待下载数据的开始时间
        report.setReportStartTime(null);
        //调用生成方法，获取reportId
        Integer reportId = DataDownloadUtils.createDownloadReport(report);

        String path = request.getSession().getServletContext().getRealPath("/excel/csv/collaborator/file/");

        //CollaboratorListDTO是分页接口的返回类，不同业务场景对应不同的返回类
        ExecutorPoolSingleton.getInstance().executeTask(() -> {
            DownloadDataLoader<ClerkDTO> loader = new DownloadDataLoader<ClerkDTO>() {
                @Override
                protected List<ClerkDTO> getDownloadData(Integer pageNum) throws Exception {
                    //调用分页查询接口
                    ServiceResponse<Page<ClerkStoreListDTO>> result = clerkApiService.listClerk(clerkSearchDTO.getEnterpriseId(), clerkSearchDTO, pageNum, 500);
                    List<ClerkStoreListDTO> clerkStoreList = result.getResult().getResult();
                    List<ClerkDTO> clerkDTOS = new ArrayList<>();
                    for (ClerkStoreListDTO clerkStoreListDTO : clerkStoreList) {
                        List<ClerkDTO> clerkList = clerkStoreListDTO.getClerkList();
                        for (ClerkDTO clerkDTO : clerkList) {
                            clerkDTO.setStoreName(clerkStoreListDTO.getStoreName());
                            clerkDTO.setHaobanStatusName(clerkDTO.getHaobanStatus() == null ? null : (clerkDTO.getHaobanStatus() == 1 ? "已绑定" : "未绑定"));
                        }
                        clerkDTOS.addAll(clerkList);
                    }
                    return clerkDTOS;
                }
            };
            try {
                //参数说明：excelExtensionCode，Excel后缀名code ，枚举类：ExcelExtensionEnum, Arrays.asList("phone")这个phone是需要加密的字段
                download(path, reportId, clerkSearchDTO.getFileName(), clerkSearchDTO.getExcelExtension(), fieldNameList, fieldCodeList, loader, Arrays.asList("phoneNumber"), null);
            } catch (Exception e) {
                logger.warn("下载错误", e);
            }
        });
        return RestResponse.success(reportId);
    }

    @RequestMapping("clerk-qrcode-download")
    public RestResponse clerkQrcodeDownload(@RequestBody ClerkQrcodeQO clerkQrcodeQO){

        List<com.gic.store.web.qo.store.QrcodeContent> list = clerkQrcodeQO.getContent();
        if (CollectionUtils.isNotEmpty(list)) {
            clerkQrcodeQO.setContent(list.stream().filter(Objects::nonNull).collect(Collectors.toList()));
        }

        int total = 0;
        if(clerkQrcodeQO.getIsAll() == 1){
            ClerkSearchDTO clerkSearchDTO = clerkQrcodeQO.getClerkSearchDTO();
            clerkSearchDTO.setEnterpriseId(UserDetailUtils.getUserDetail().getEnterpriseId());
            ServiceResponse<Integer> totalClerkServiceResponse = clerkApiService.getTotalClerk(UserDetailUtils.getUserDetail().getEnterpriseId(), clerkSearchDTO);
            total = totalClerkServiceResponse.getResult();
            if (totalClerkServiceResponse.getResult() == 0) {
                return RestResponse.failure(ErrorCode.NOTEXISTS.getCode(), ErrorCode.NOTEXISTS.getMsg());
            }
        } else {
            total = clerkQrcodeQO.getContent().size();
        }
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        new QrcodeDownload(){
            @Override
            public List<QrcodeContent> getContent(int pageNum, int pageSize){
                if(clerkQrcodeQO.getIsAll() == 1){
                    ClerkSearchDTO clerkSearchDTO = clerkQrcodeQO.getClerkSearchDTO();
                    clerkSearchDTO.setEnterpriseId(enterpriseId);
                    ServiceResponse<Page<ClerkStoreListDTO>> result = clerkApiService.listClerk(enterpriseId, clerkSearchDTO, pageNum, 500);
                    List<ClerkStoreListDTO> clerkStoreList = result.getResult().getResult();
                    List<QrcodeContent> clerkDTOS = new ArrayList<>();
                    for (ClerkStoreListDTO clerkStoreListDTO : clerkStoreList) {
                        List<ClerkDTO> clerkList = clerkStoreListDTO.getClerkList();
                        for (ClerkDTO clerkDTO : clerkList) {
                            QrcodeContent qrcodeContent = new QrcodeContent();
                            qrcodeContent.setTitle(clerkDTO.getClerkName());
                            qrcodeContent.setCustomParams(clerkDTO.getClerkId()+"");
                            clerkDTOS.add(qrcodeContent);
                        }
                    }
                    return clerkDTOS;
                }else {
                    return EntityUtil.changeEntityListByJSON(QrcodeContent.class, clerkQrcodeQO.getContent());
                }
            }
        }.takeQrcode(EntityUtil.changeEntityByJSON(com.gic.download.qo.QrcodeQO.class, clerkQrcodeQO), total, QrcodeTypeEnum.CLERK.getType(),
                downloadReportApiService, weixinBaseFunService, weixinWxaFunService, qrCodeApiService);
        return RestResponse.success();
    }

    private String getDataContent() {
        String dataContent;
        Integer moduleMenuId = (Integer) RequestContext.getContext().getRequest().getAttribute("moduleMenuId");
        ServiceResponse<MenuDTO> response = menuApiService.getDetailById(moduleMenuId);
        MenuDTO menuDTO = response.getResult();
        ServiceResponse<MenuDTO> parentResponse = menuApiService.getDetailById(menuDTO.getParentId());
        MenuDTO parentMenuDTO = parentResponse.getResult();
        if (parentMenuDTO != null) {
            dataContent = parentMenuDTO.getMenuName() + "-" + menuDTO.getMenuName();
        } else {
            dataContent = menuDTO.getMenuName();
        }
        return dataContent;
    }

    @RequestMapping("/save-clerk")
    public RestResponse save(@Validated(ClerkQO.SaveValidView.class) ClerkQO clerkQO) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        ClerkDTO clerkDTO = EntityUtil.changeEntityByOrika(ClerkDTO.class, clerkQO);
        clerkDTO.setEnterpriseId(enterpriseId);
        clerkDTO.setReason(ClerkLogReasonEnum.WEB.getCode());
        if (clerkQO.getClerkId() == null) {
            clerkDTO.setRemark("手工新增");
        } else {
            clerkDTO.setRemark("单个编辑");
        }
        clerkDTO.setOperatorId(UserDetailUtils.getUserDetail().getUserId());
        clerkDTO.setOperatorName(UserDetailUtils.getUserDetail().getUserInfo().getUserName());
        if (!com.gic.store.constant.Constants.CLERK_LEADER_POSITION_ID.equals(clerkQO.getPositionId())) {
            // 如果门店下只有一个导购 就不能修改店长
            List<ClerkDTO> dtoList = clerkApiService.listClerkByStoreInfoId(enterpriseId, clerkQO.getStoreInfoId(), null).getResult();
            if (CollectionUtils.isNotEmpty(dtoList) && dtoList.size() == 1) {
                return RestResponse.failure("0001", "门店下必须存在一名启用状态的店长");
            }
        }
        ServiceResponse serviceResponse = clerkApiService.saveOrUpdate(clerkDTO);
        if (serviceResponse.isSuccess()) {
            LogUtils.createLog((clerkQO.getClerkId() == null ? "新增" : "编辑") + "导购", clerkQO.getClerkName());
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }

    @RequestMapping("/list-clerk")
    public RestResponse listClerk(@RequestBody ClerkSearchDTO clerkSearchDTO) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        clerkSearchDTO.setEnterpriseId(enterpriseId);
        ServiceResponse serviceResponse = clerkApiService.listClerk(enterpriseId, clerkSearchDTO, clerkSearchDTO.getCurrentPage(), clerkSearchDTO.getPageSize());
        if (serviceResponse.isSuccess()) {
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }

    @RequestMapping("/get-clerk-header")
    public RestResponse listClerk(Integer storeId) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        ServiceResponse<ClerkDTO> serviceResponse = clerkApiService.getHeadClerk(enterpriseId, storeId);
        if (serviceResponse.isSuccess()) {
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }

    @RequestMapping("/count-clerk")
    public RestResponse countClerk(@RequestBody ClerkSearchDTO clerkSearchDTO) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        clerkSearchDTO.setEnterpriseId(enterpriseId);
        clerkSearchDTO.setStatus(1);
        ServiceResponse serviceResponse = clerkApiService.getTotalClerk(enterpriseId, clerkSearchDTO);
        if (serviceResponse.isSuccess()) {
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }

    @RequestMapping("/update-clerk-status")
    public RestResponse updateClerkStatus(String clerkIds, Integer status) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        ServiceResponse serviceResponse = clerkApiService.updateClerkStatus(enterpriseId, clerkIds, status);

        if (serviceResponse.isSuccess()) {
            if (!StringUtils.equals(com.gic.store.constant.Constants.ALL, clerkIds)) {
                ServiceResponse<List<ClerkDTO>> listClerkByIds = clerkApiService.listClerkByIds(enterpriseId, clerkIds);
                List<ClerkDTO> clerkList = listClerkByIds.getResult();
                if (CollectionUtils.isNotEmpty(clerkList)) {
                    String clerkNames = clerkList.stream().map(ClerkDTO::getClerkName).collect(Collectors.joining(","));
                    String statusName = (Constants.NORMAL_STATUS.equals(status)) ? "启用" : "禁用";
                    LogUtils.createLog("修改状态为" + statusName, clerkNames);
                }
            } else {
                String statusName = (Constants.NORMAL_STATUS.equals(status)) ? "启用" : "禁用";
                LogUtils.createLog("修改状态为" + statusName, "全部导购");
            }
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }

    @RequestMapping("/update-clerk-leader")
    public RestResponse updateClerkLeader(Integer clerkId) {
        ServiceResponse serviceResponse = clerkApiService.updateClerkLeader(clerkId);
        return ResultControllerUtils.commonResult(serviceResponse);
    }

    @RequestMapping("/list-clerk-in-store")
    public RestResponse listClerkInStore(Integer storeInfoId, String search) {
        ServiceResponse<List<ClerkDTO>> serviceResponse = clerkApiService.listClerkByStoreInfoId(UserDetailUtils.getUserDetail().getEnterpriseId(), storeInfoId, search);
        return ResultControllerUtils.commonResult(serviceResponse);
    }

    @RequestMapping("/list-clerk-log")
    public RestResponse listClerkLog(PageQO pageQO, String search, Integer reason, Integer logType, Integer clerkId, String startTime, String endTime) {
        ClerkLogDTO clerkLogDTO = new ClerkLogDTO();
        clerkLogDTO.setContent(search);
        clerkLogDTO.setReason(reason);
        clerkLogDTO.setLogType(logType);
        clerkLogDTO.setClerkId(clerkId);
        if (StringUtils.isNotBlank(startTime)) {
            clerkLogDTO.setStartTime(startTime + " 00:00:00");
        }
        if (StringUtils.isNotBlank(endTime)) {
            clerkLogDTO.setEndTime(endTime + " 23:59:59");
        }
        ServiceResponse<Page<ClerkLogDTO>> response = clerkLogApiService.listClerkLog(clerkLogDTO, pageQO.getCurrentPage(), pageQO.getPageSize());
        return ResultControllerUtils.commonResult(response);
    }
    @RequestMapping("search-clerk")
    public RestResponse searchClerk(String search){
        if(StringUtils.isBlank(search)){
            return RestResponse.success();
        }
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        ClerkSearchDTO clerkSearchDTO = new ClerkSearchDTO();
        clerkSearchDTO.setEnterpriseId(enterpriseId);
        clerkSearchDTO.setSearch(search);
        ServiceResponse<Page<ClerkStoreListDTO>> response = this.clerkApiService.listClerk(enterpriseId, clerkSearchDTO, 1, 200);
        if(response.isSuccess() && response.getResult()!= null){
            return RestResponse.success(response.getResult().getResult());
        }
        return RestResponse.success();
    }

    enum ClerkFiledEnum{
        /**
         * 所属门店
         */
        storeName("storeName", "所属门店", 0),
        /**
         * 店员名称
         */
        clerkName("clerkName", "店员名称", 0),
        /**
         * 职位
         */
        positionName("positionName", "职位", 0),
        /**
         * 手机号
         */
        phoneNumber("phoneNumber", "手机号", 1),
        /**
         * 好办状态
         */
        haobanStatusName("haobanStatusName", "好办状态", 0);
        ;

        private String fieldCode;
        private String fieldName;
        private Integer needEncrypt;

        ClerkFiledEnum(String fieldCode, String fieldName, Integer needEncrypt) {
            this.fieldCode = fieldCode;
            this.fieldName = fieldName;
            this.needEncrypt = needEncrypt;
        }

        public String getFieldCode() {
            return fieldCode;
        }

        public String getFieldName() {
            return fieldName;
        }

        public Integer getNeedEncrypt() {
            return needEncrypt;
        }
    }

}
