package com.gic.store.web.controller;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.download.utils.log.LogUtils;
import com.gic.enterprise.utils.UserDetailUtils;
import com.gic.store.constant.StoreOwnTypeEnum;
import com.gic.store.dto.StoreRegionDTO;
import com.gic.store.service.StoreRegionApiService;
import com.gic.store.web.qo.PageQO;
import com.gic.store.web.qo.region.StoreRegionQO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @author zhiwj
 * @date 2019/6/25
 */
@RestController
public class StoreRegionController {

    @Autowired
    private StoreRegionApiService storeRegionApiService;

    @RequestMapping("/save-store-region")
    public RestResponse saveStoreRegion(@Validated({StoreRegionQO.SaveValidView.class}) StoreRegionQO storeRegionQO) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        ServiceResponse<Integer> serviceResponse = storeRegionApiService.saveOrUpdateStoreRegion(enterpriseId, storeRegionQO.getRegionCode(), storeRegionQO.getRegionName(), storeRegionQO.getRegionId());
        if (serviceResponse.isSuccess()) {
            LogUtils.createLog((storeRegionQO.getRegionId() == null ? "新增" : "修改") + "门店域", storeRegionQO.getRegionName());
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }

    @RequestMapping("/page-store-region")
    public RestResponse pageStoreRegion(String search, PageQO pageQO) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        ServiceResponse<Page<StoreRegionDTO>> serviceResponse = storeRegionApiService.listStoreRegion(enterpriseId, search, pageQO.getCurrentPage(), pageQO.getPageSize());
        if (serviceResponse.isSuccess()) {
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }

    @RequestMapping("/list-store-region")
    public RestResponse listStoreRegion(String search) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        ServiceResponse<List<StoreRegionDTO>> serviceResponse = storeRegionApiService.listStoreRegion(enterpriseId, search, StoreOwnTypeEnum.OWNER.getCode());
        if (serviceResponse.isSuccess()) {
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }



}
