package com.gic.store.web.controller;

import com.alibaba.fastjson.JSONObject;
import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.download.utils.OperationResultUtils;
import com.gic.enterprise.ano.IgnoreLogin;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.response.EnterpriseRestResponse;
import com.gic.enterprise.utils.ResultControllerUtils;
import com.gic.enterprise.utils.UserDetailUtils;
import com.gic.store.constant.Constants;
import com.gic.store.dto.*;
import com.gic.store.service.*;
import com.gic.store.web.qo.PageQO;
import com.gic.store.web.utils.ExcelUtils;
import com.gic.store.web.vo.StoreTagErrorListVO;
import com.gic.store.web.vo.StoreTagVO;
import com.gic.store.web.vo.storewidget.StoreWidgetSearch;
import com.gic.store.web.vo.storewidget.StoreWidgetWriteBack;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.apache.poi.ss.usermodel.Workbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 
 * @ClassName: StoreTagController
 * @Description:  
 * @author zhiwj
 * @date 2020-09-09 19:23
 */
@RestController
@RequestMapping("/store-tag")
public class StoreTagController {
    private static final Logger LOGGER = LogManager.getLogger(StoreTagController.class);

    @Autowired
    private StoreTagApiService storeTagApiService;
    @Autowired
    private StoreWidgetApiService storeWidgetApiService;
    @Autowired
    private StoreApiService storeApiService;
    @Autowired
    private StoreTagTmpApiService storeTagTmpApiService;
    @Autowired
    private StoreRegionApiService storeRegionApiService;


    @RequestMapping("/save-store-tag")
    public RestResponse save(StoreTagDTO dto, MultipartFile file, Integer dataType) {
        dto.setEnterpriseId(UserDetailUtils.getUserDetail().getEnterpriseId());
        if (dataType != null && dataType.equals(Constants.STORE_TAG_IMPORT)) {
            Map<String, Object> map = parseFile(file, null);
            Object msg = map.get("msg");
            if (msg != null) {
                return RestResponse.failure(ErrorCode.OPERATION_FAILED.getCode(), msg.toString());
            }
            Integer storeWidgetId = (Integer) map.get("storeWidgetId");
            dto.setStoreWidgetId(storeWidgetId);
        }
        return OperationResultUtils.operationResult(storeTagApiService.save(dto), OperationResultUtils.LOG_NEW + "门店标签",
                dto.getStoreTagName());
    }

    @RequestMapping("/edit-store-tag")
    public RestResponse edit(StoreTagDTO dto, MultipartFile file, Integer dataType) {
        if (dataType != null && dataType.equals(Constants.STORE_TAG_IMPORT)) {
            Map<String, Object> map = parseFile(file, dto.getStoreWidgetId());
            Object msg = map.get("msg");
            if (msg != null) {
                return RestResponse.failure(ErrorCode.OPERATION_FAILED.getCode(), msg.toString());
            }
            Integer storeWidgetId = (Integer) map.get("storeWidgetId");
            dto.setStoreWidgetId(storeWidgetId);
        }
        return OperationResultUtils.operationResult(storeTagApiService.update(dto),
                OperationResultUtils.LOG_EDIT + "门店标签", dto.getStoreTagName());
    }

    @RequestMapping("/delete-store-tag")
    public RestResponse delete(Integer storeTagId) {
        ServiceResponse<String> result = storeTagApiService.delete(storeTagId);
        return OperationResultUtils.operationResult(result, OperationResultUtils.LOG_DELETE + "门店标签",
                OperationResultUtils.getOperationObject(result));
    }

    @RequestMapping("/template-download")
    @IgnoreLogin
    public Object download(HttpServletRequest request, HttpServletResponse response) throws Exception {
        String fileName = " 门店标签批量导入模板.xlsx";

        OutputStream fo = null;
        InputStream in = null;
        try {
            response.setContentType("text/html;charset=gbk");
            response.setHeader("Content-Disposition",
                    "attachment; filename=" + new String(fileName.getBytes("gbk"), "ISO-8859-1"));

            fo = response.getOutputStream();
            in = this.getClass().getClassLoader().getResourceAsStream("excel/store_tag_batch_import.xlsx");
            byte[] b = new byte[1024];
            int len = 0;
            while ((len = in.read(b)) != -1) {
                fo.write(b, 0, len);
            }
            fo.flush();
        } catch (Exception e) {
            LOGGER.info("下载错误", e);
        } finally {
            if (fo != null) {
                fo.close();
            }
            if (in != null) {
                in.close();
            }
        }
        return RestResponse.success();
    }

    @RequestMapping("/list-store-tag")
    public RestResponse list() {
        return ResultControllerUtils.commonResult(
                storeTagApiService.listByEnterprise(UserDetailUtils.getUserDetail().getEnterpriseId()),
                StoreTagVO.class);
    }

    @RequestMapping("/list-store-by-tag")
    public RestResponse listStoreByTag(Integer storeTagId, String search, @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum, @RequestParam(value = "pageSize", defaultValue = "20") Integer pageSize) {
        ServiceResponse<StoreTagDTO> result = storeTagApiService.getByStoreTagId(storeTagId);
        if (result.isSuccess()) {
            ServiceResponse<StoreWidgetDTO> storeWidgetResult = storeWidgetApiService
                    .getStoreWidget(result.getResult().getStoreWidgetId());
            if (storeWidgetResult.isSuccess()) {
                StoreWidgetDTO storeWidgetDTO = storeWidgetResult.getResult();
                String authSearchParam = storeWidgetDTO.getAuthSearchParam();
                String searchParam = storeWidgetDTO.getSearchParam();
                StoreSearchDTO dto = new StoreSearchDTO();
                //名称
                dto.setSearch(search);
                //代码
                dto.setStoreCode(search);
                dto.setEnterpriseId(UserDetailUtils.getUserDetail().getEnterpriseId());
                if(StringUtils.isNotBlank(authSearchParam) && !Constants.EMPTY_JSON.equals(authSearchParam)){
                    dto.setAuthSearchJson(authSearchParam);
                }
                dto.setSearchJson(searchParam);
                return ResultControllerUtils.commonResult(this.storeApiService.listStore(dto, pageNum, pageSize));
            }
            return EnterpriseRestResponse.failure(storeWidgetResult);
        }
        return EnterpriseRestResponse.failure(result);
    }


    @RequestMapping("/list-import-error")
    public RestResponse listImportError(PageQO pageQO) {
        ServiceResponse<Page<StoreTagTmpDTO>> serviceResponse = this.storeTagTmpApiService.listImportError(UserDetailUtils.getUserDetail().getEnterpriseId(), pageQO.getCurrentPage(), pageQO.getPageSize());
        if (serviceResponse.isSuccess()) {
            StoreTagErrorListVO vo = EntityUtil.changeEntityByJSON(StoreTagErrorListVO.class, serviceResponse.getResult());
            ServiceResponse<JSONObject> countResponse = storeTagTmpApiService.queryCount(UserDetailUtils.getUserDetail().getEnterpriseId());
            JSONObject result = countResponse.getResult();
            vo.setSuccessCount(result.getInteger("successCount"));

            return RestResponse.success(vo);
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }

    private Map<String, Object> parseFile(MultipartFile file, Integer storeWidgetId) {
        Map<String, Object> resultMap = new HashMap<>(4);
        if (file.getSize() > 0) {
            String fileName = file.getOriginalFilename();
            if (fileName.endsWith(Constants.XLSX)) {
                try {
                    Workbook workbook = ExcelUtils.getWorkbookFromUpload(file.getInputStream(), fileName);
                    List<Map<Integer, String>> data = ExcelUtils.readExcel(2, fileName.substring(fileName.lastIndexOf(".") + 1), workbook, null);
                    //三列 门店名称、门店code、门店域名
                    int total = 3;
                    if (data.size() > 0 && data.get(0).size() != total) {
                        resultMap.put("msg", "总列数与模板不一致");
                    }
                    //删除临时表数据
                    storeTagTmpApiService.delStoreTagTmp(UserDetailUtils.getUserDetail().getEnterpriseId());
                    List<Integer> storeIdList = new ArrayList<>();
                    List<String> storeNameList = new ArrayList<>();
                    for (Map<Integer, String> row : data) {
                        StoreTagTmpDTO bean = this.validateData(row, UserDetailUtils.getUserDetail().getEnterpriseId());
                        try {
                            //
                            if (StringUtils.isBlank(bean.getErrorMessage())) {
                                //如果是校验通过的，则
                                storeIdList.add(bean.getStoreId());
                                storeNameList.add(bean.getStoreName());
                            }
                            // 保存数据到临时表
                            storeTagTmpApiService.saveStoreTagTmp(bean);
                        } catch (Exception e) {
                            LOGGER.info("检验保存门店分组错误", e);
                        }
                    }
                    //生成门店控件ID
                    if (CollectionUtils.isEmpty(storeNameList)) {
                        resultMap.put("msg", "没有能导入的门店");
                    }else {
                        StoreWidgetDTO storeWidgetDTO;
                        if (storeWidgetId != null) {
                            storeWidgetDTO = this.storeWidgetApiService.getStoreWidget(storeWidgetId).getResult();
                        } else {
                            storeWidgetDTO = new StoreWidgetDTO();
                        }
                        storeWidgetDTO.setWriteBackParam(StoreWidgetWriteBack.getJson(storeNameList, storeIdList));
                        storeWidgetDTO.setSearchParam(StoreWidgetSearch.getJson(storeIdList));
                        storeWidgetId = this.storeWidgetApiService.saveStoreWidget(storeWidgetDTO).getResult();
                        resultMap.put("storeWidgetId", storeWidgetId);
                    }
                } catch (IOException e) {
                    LOGGER.info("检验保存门店分组错误", e);
                }
            } else {
                resultMap.put("msg", "选择excel格式文件上传");
            }
        } else {
            resultMap.put("msg", "选择excel格式文件上传");
        }
        return resultMap;
    }

    private StoreTagTmpDTO validateData(Map<Integer, String> row, Integer enterpriseId) {
        String storeName = row.get(0);
        String storeCode = row.get(1);
        String regionName = row.get(2);

        StoreTagTmpDTO storeTagTmpDTO = new StoreTagTmpDTO();
        storeTagTmpDTO.setEnterpriseId(enterpriseId);
        storeTagTmpDTO.setStoreName(storeName);
        storeTagTmpDTO.setStoreCode(storeCode);
        storeTagTmpDTO.setRegionName(regionName);

        if (StringUtils.isBlank(storeName)) {
            storeTagTmpDTO.setErrorMessage("门店名称不能为空");
            return storeTagTmpDTO;
        }
        if (StringUtils.isBlank(storeCode)) {
            storeTagTmpDTO.setErrorMessage("门店code不能为空");
            return storeTagTmpDTO;
        }
        if (StringUtils.isBlank(regionName)) {
            storeTagTmpDTO.setErrorMessage("门店域不能为空");
            return storeTagTmpDTO;
        }

        storeTagTmpDTO.setStoreName(storeTagTmpDTO.getStoreName().trim());
        storeTagTmpDTO.setStoreCode(storeTagTmpDTO.getStoreCode().trim());
        storeTagTmpDTO.setRegionName(storeTagTmpDTO.getRegionName().trim());

        ServiceResponse<StoreRegionDTO> region = this.storeRegionApiService.getStoreRegionByRegionName(enterpriseId, regionName);

        StoreRegionDTO regionDTO = region.getResult();
        if (regionDTO == null) {
            storeTagTmpDTO.setErrorMessage("门店域不存在");
            return storeTagTmpDTO;
        }
        Integer storeId = this.storeApiService.getStoreIdByStoreNameAndStoreCodeAndRegionId(storeCode, regionDTO.getRegionId(), enterpriseId).getResult();
        if (storeId == null) {
            storeTagTmpDTO.setErrorMessage("不存在该门店");
        }
        storeTagTmpDTO.setStoreId(storeId);

        return storeTagTmpDTO;
    }

}
